(copyright)
kpty.cpp
diff --git a/kdecore/Mainpage.dox b/kdecore/Mainpage.dox
index 987080ad2..c0e13a339 100644
--- a/kdecore/Mainpage.dox
+++ b/kdecore/Mainpage.dox
@@ -5,7 +5,7 @@ as the configuration system, IPC, internationalization and locale
support, site-independent access to the filesystem and a large number
of other (but no less important) things.
-All Trinity applications should link to the kdecore library. Also, using a
+All Trinity applications should link to the tdecore library. Also, using a
KApplication derived class instead of TQApplication is almost
mandatory if you expect your application to behave nicely within the
Trinity environment.
diff --git a/kdecore/Makefile.am b/kdecore/Makefile.am
index 32ccec1ca..92ee7ebfc 100644
--- a/kdecore/Makefile.am
+++ b/kdecore/Makefile.am
@@ -20,7 +20,7 @@
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301, USA.
-INCLUDES = -I$(top_srcdir)/kdefx -I$(top_srcdir)/kdecore/network $(all_includes) $(LIBART_CFLAGS)
+INCLUDES = -I$(top_srcdir)/tdefx -I$(top_srcdir)/tdecore/network $(all_includes) $(LIBART_CFLAGS)
if include_SVGICONS
SVGICONS=svgicons
@@ -117,20 +117,20 @@ libtdecore_la_SOURCES = libintl.cpp kapplication.cpp \
kcalendarsystemhijri.cpp kcalendarsystemhebrew.cpp \
kcalendarsystemfactory.cpp kmacroexpander.cpp kidna.cpp \
ktempdir.cpp kshell.cpp kmountpoint.cpp kcalendarsystemjalali.cpp \
- kprotocolinfo_kdecore.cpp kprotocolinfofactory.cpp kxerrorhandler.cpp \
+ kprotocolinfo_tdecore.cpp kprotocolinfofactory.cpp kxerrorhandler.cpp \
kuser.cpp kconfigskeleton.cpp kconfigdialogmanager.cpp klockfile.cpp \
kqiodevicegzip_p.cpp ktimezones.cpp
libtdecore_la_LDFLAGS = $(QT_LDFLAGS) $(KDE_RPATH) $(KDE_MT_LDFLAGS) $(X_LDFLAGS) $(USER_LDFLAGS) -version-info 6:0:2 -no-undefined
libtdecore_la_LIBADD = malloc/libklmalloc.la network/libtdecorenetwork.la $(SVGICON_LIB) ../dcop/libDCOP.la ../libltdl/libltdlc.la \
- $(LIBART_LIBS) $(LIB_IDN) $(top_builddir)/kdefx/libtdefx.la $(LIB_QT) $(LIBSM) $(LIB_X11) $(LIBZ) $(LIBDL)
+ $(LIBART_LIBS) $(LIB_IDN) $(top_builddir)/tdefx/libtdefx.la $(LIB_QT) $(LIBSM) $(LIB_X11) $(LIBZ) $(LIBDL)
libtdecore_la_NMCHECK = $(srcdir)/libtdecore.nmcheck
libtdecore_la_NMCHECKWEAK = $(srcdir)/libtdecore_weak.nmcheck $(srcdir)/libqt-mt_weak.nmcheck \
- $(top_srcdir)/dcop/libDCOP_weak.nmcheck $(top_srcdir)/kdecore/standard_weak.nmcheck
+ $(top_srcdir)/dcop/libDCOP_weak.nmcheck $(top_srcdir)/tdecore/standard_weak.nmcheck
libtdecore_la_METASOURCES = AUTO
-SRCDOC_DEST=$(kde_htmldir)/en/kdelibs/kdecore
+SRCDOC_DEST=$(kde_htmldir)/en/kdelibs/tdecore
kdebugdir = $(kde_confdir)
kdebug_DATA = kdebug.areas kdebugrc language.codes
@@ -154,7 +154,7 @@ install-data-local:
uninstall-local:
-rm -f $(DESTDIR)$(includedir)/kio/kmdcodec.h
-# If you add a color palette file here, please change kdelibs/kdeui/kcolordialog.cpp too to allow to translate the name
+# If you add a color palette file here, please change kdelibs/tdeui/kcolordialog.cpp too to allow to translate the name
colors_DATA = 40.colors Web.colors Royal.colors Rainbow.colors
colorsdir = $(kde_confdir)/colors
@@ -188,7 +188,7 @@ install-exec-hook:
DISTCLEANFILES = kde-config.cpp
-DOXYGEN_REFERENCES = dcop kdeui kparts kio
+DOXYGEN_REFERENCES = dcop tdeui kparts kio
DOXYGEN_EXCLUDE = malloc kde_file.h
DOXYGEN_SET_WARN_IF_UNDOCUMENTED = YES
diff --git a/kdecore/README b/kdecore/README
index 0788341af..ec99f440f 100644
--- a/kdecore/README
+++ b/kdecore/README
@@ -1,3 +1,3 @@
-This is the KDE "core" library. The kdecore library provides basic non user
+This is the KDE "core" library. The tdecore library provides basic non user
interface functionality.
diff --git a/kdecore/README.kstartupinfo b/kdecore/README.kstartupinfo
index 233ccde1e..cbb6a6dfb 100644
--- a/kdecore/README.kstartupinfo
+++ b/kdecore/README.kstartupinfo
@@ -88,7 +88,7 @@ The KStartupInfo classes :
--------------------------
In some cases, or if you are interested in getting the ASN information, you
-have to use the KStartupInfo classes in kdelibs/kdecore.
+have to use the KStartupInfo classes in kdelibs/tdecore.
Receiving the application startup notification information :
------------------------------------------------------------
diff --git a/kdecore/configure.in.in b/kdecore/configure.in.in
index b2fe9bd6e..7439a7c12 100644
--- a/kdecore/configure.in.in
+++ b/kdecore/configure.in.in
@@ -1,7 +1,7 @@
dnl Compile in the exec prefix to help kstddirs in finding dynamic libs
AC_DEFINE_UNQUOTED(__KDE_EXECPREFIX, "$exec_prefix", [execprefix or NONE if not set, for libloading])
-dnl Compile in kde_bindir to safely find kdesu_stub.
+dnl Compile in kde_bindir to safely find tdesu_stub.
if test "$exec_prefix" = "NONE"; then
bindir_str="\"$prefix/bin\""
else
@@ -167,9 +167,9 @@ AC_TRY_LINK(dnl
AC_CHECK_HEADERS(sys/mount.h)
-dnl AC_OUTPUT(kdecore/kde-config.cpp)
+dnl AC_OUTPUT(tdecore/kde-config.cpp)
-AM_CONFIG_HEADER(kdecore/kdemacros.h)
+AM_CONFIG_HEADER(tdecore/kdemacros.h)
SVGICONS=
diff --git a/kdecore/kaccel.cpp b/kdecore/kaccel.cpp
index 75cd7aecf..b1fe773c6 100644
--- a/kdecore/kaccel.cpp
+++ b/kdecore/kaccel.cpp
@@ -523,7 +523,7 @@ bool KAccel::setShortcut( const TQString& sAction, const KShortcut& cut )
const TQString& KAccel::configGroup() const
{ return d->configGroup(); }
-// for kdegames/ksirtet
+// for tdegames/ksirtet
void KAccel::setConfigGroup( const TQString& s )
{ d->setConfigGroup( s ); }
diff --git a/kdecore/kaccelmanager.cpp b/kdecore/kaccelmanager.cpp
index 7dc49ce78..6e8f08e0a 100644
--- a/kdecore/kaccelmanager.cpp
+++ b/kdecore/kaccelmanager.cpp
@@ -46,7 +46,7 @@
#include "kaccelmanager_private.h"
-#include "../kdeui/kstdaction_p.h"
+#include "../tdeui/kstdaction_p.h"
#include "../kutils/kmultitabbar.h"
diff --git a/kdecore/kconfig.cpp b/kdecore/kconfig.cpp
index 2531034ee..709e39de3 100644
--- a/kdecore/kconfig.cpp
+++ b/kdecore/kconfig.cpp
@@ -294,7 +294,7 @@ void KConfig::checkUpdate(const TQString &id, const TQString &updateFile)
{
TQStringList args;
args << "--check" << updateFile;
- KApplication::kdeinitExecWait("kconf_update", args);
+ KApplication::tdeinitExecWait("kconf_update", args);
reparseConfiguration();
}
setGroup(oldGroup);
diff --git a/kdecore/kconfig_compiler/CMakeLists.txt b/kdecore/kconfig_compiler/CMakeLists.txt
index d256d21c3..4acc09f51 100644
--- a/kdecore/kconfig_compiler/CMakeLists.txt
+++ b/kdecore/kconfig_compiler/CMakeLists.txt
@@ -11,8 +11,8 @@
include_directories(
${TQT_INCLUDE_DIRS}
- ${CMAKE_BINARY_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdecore
+ ${CMAKE_BINARY_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdecore
)
link_directories(
@@ -24,6 +24,6 @@ link_directories(
tde_add_executable( kconfig_compiler
SOURCES kconfig_compiler.cpp
- LINK kdecore-shared
+ LINK tdecore-shared
DESTINATION ${BIN_INSTALL_DIR}
)
diff --git a/kdecore/kconfig_compiler/Makefile.am b/kdecore/kconfig_compiler/Makefile.am
index e80f24d0e..d7b1400a4 100644
--- a/kdecore/kconfig_compiler/Makefile.am
+++ b/kdecore/kconfig_compiler/Makefile.am
@@ -1,10 +1,10 @@
SUBDIRS = example tests
-AM_CPPFLAGS = -I$(top_srcdir)/kdecore -I$(top_srcdir) $(all_includes)
+AM_CPPFLAGS = -I$(top_srcdir)/tdecore -I$(top_srcdir) $(all_includes)
bin_PROGRAMS = kconfig_compiler
-kconfig_compiler_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kconfig_compiler_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
kconfig_compiler_LDADD = $(LIB_KDECORE)
kconfig_compiler_SOURCES = kconfig_compiler.cpp
@@ -13,6 +13,6 @@ TESTFILES = test1.kcfg test2.kcfg test3.kcfg test4.kcfg test_dpointer.kcfg
check-local:
for i in $(TESTFILES); \
do xmllint --noout --schema $(srcdir)/kcfg.xsd $(srcdir)/tests/$$i; \
- perl $(top_srcdir)/kdecore/kconfig_compiler/checkkcfg.pl \
- $(top_srcdir)/kdecore/kconfig_compiler/tests/$$i; done
+ perl $(top_srcdir)/tdecore/kconfig_compiler/checkkcfg.pl \
+ $(top_srcdir)/tdecore/kconfig_compiler/tests/$$i; done
diff --git a/kdecore/kconfig_compiler/example/Makefile.am b/kdecore/kconfig_compiler/example/Makefile.am
index 4359c429e..9c0454ad8 100644
--- a/kdecore/kconfig_compiler/example/Makefile.am
+++ b/kdecore/kconfig_compiler/example/Makefile.am
@@ -1,13 +1,13 @@
-AM_CPPFLAGS = -I$(top_srcdir)/kdecore -I$(top_srcdir) $(all_includes)
+AM_CPPFLAGS = -I$(top_srcdir)/tdecore -I$(top_srcdir) $(all_includes)
check_PROGRAMS = example # autoexample
EXTRA_PROGRAMS = autoexample
-example_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+example_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
example_LDADD = $(LIB_KDECORE)
example_SOURCES = example.cpp exampleprefs_base.cpp
-autoexample_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+autoexample_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
autoexample_LDADD = $(LIB_KDECORE) $(LIB_KDEUI)
autoexample_SOURCES = exampleprefs_base.cpp general_base.ui myoptions_base.ui \
autoexample.cpp
diff --git a/kdecore/kconfig_compiler/tests/Makefile.am b/kdecore/kconfig_compiler/tests/Makefile.am
index 01a510f31..0b47449fa 100644
--- a/kdecore/kconfig_compiler/tests/Makefile.am
+++ b/kdecore/kconfig_compiler/tests/Makefile.am
@@ -1,4 +1,4 @@
-AM_CPPFLAGS = -I$(top_srcdir)/kdecore -I$(top_srcdir)/kunittest $(all_includes) -DQT_NO_CAST_ASCII -DSRCDIR=\"$(srcdir)\"
+AM_CPPFLAGS = -I$(top_srcdir)/tdecore -I$(top_srcdir)/kunittest $(all_includes) -DQT_NO_CAST_ASCII -DSRCDIR=\"$(srcdir)\"
check_PROGRAMS = test1 test2 test3 test4 test5 test6 test7 test8 test9 test_dpointer
@@ -14,43 +14,43 @@ CLEANFILES = test1.cpp test1.h \
test_dpointer.cpp test_dpointer.h \
md5sums
-test1_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test1_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test1_LDADD = $(LIB_KDECORE)
test1_SOURCES = test1main.cpp test1.cpp
-test2_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test2_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test2_LDADD = $(LIB_KDECORE)
test2_SOURCES = test2main.cpp test2.cpp
-test3_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test3_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test3_LDADD = $(LIB_KDECORE)
test3_SOURCES = test3main.cpp test3.cpp
-test4_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test4_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test4_LDADD = $(LIB_KDECORE)
test4_SOURCES = test4main.cpp test4.cpp
-test5_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test5_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test5_LDADD = $(LIB_KDECORE)
test5_SOURCES = test5main.cpp test5.cpp
-test6_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test6_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test6_LDADD = $(LIB_KDECORE)
test6_SOURCES = test6main.cpp test6.cpp
-test7_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test7_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test7_LDADD = $(LIB_KDECORE)
test7_SOURCES = test7main.cpp test7.cpp
-test8_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test8_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test8_LDADD = $(LIB_KDECORE)
test8_SOURCES = test8main.cpp test8a.cpp test8b.cpp
-test9_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test9_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test9_LDADD = $(LIB_KDECORE)
test9_SOURCES = test9main.cpp test9.cpp
-test_dpointer_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+test_dpointer_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
test_dpointer_LDADD = $(LIB_KDECORE)
test_dpointer_SOURCES = test_dpointer_main.cpp test_dpointer.cpp
diff --git a/kdecore/kdebug.areas b/kdecore/kdebug.areas
index e4c526be1..efa46034c 100644
--- a/kdecore/kdebug.areas
+++ b/kdecore/kdebug.areas
@@ -5,48 +5,48 @@
#
#Format : numberdescription
-125 kdecore (KAccel)
-126 kdecore (KURL)
+125 tdecore (KAccel)
+126 tdecore (KURL)
127 kio (KProtocolInfo)
-128 kdecore (KRegExp)
-129 kdecore (KAction)
+128 tdecore (KRegExp)
+129 tdecore (KAction)
130 kio (KPasswdServer)
-131 kdecore (KAcceleratorManager)
-150 kdecore (KLibLoader)
-160 kdecore (KNotifyClient)
-170 kdecore (KNetwork socket)
-171 kdecore (KSocks)
-172 kdecore (KStartupInfo)
-173 kdecore (KLocale)
-174 kdecore (KProcIO)
-175 kdecore (KProcess)
-176 kdecore (KWin)
-177 kdecore (KConfigSkeleton)
-178 kdecore (KConfigDialogManager)
-179 kdecore (KNetwork resolver)
-180 kdecore (kdelibs)
-200 kdeui (KMainWindow)
-220 kdeui (KToolBar)
-230 kdeui (KCommand)
-240 kdeui (kdelibs)
+131 tdecore (KAcceleratorManager)
+150 tdecore (KLibLoader)
+160 tdecore (KNotifyClient)
+170 tdecore (KNetwork socket)
+171 tdecore (KSocks)
+172 tdecore (KStartupInfo)
+173 tdecore (KLocale)
+174 tdecore (KProcIO)
+175 tdecore (KProcess)
+176 tdecore (KWin)
+177 tdecore (KConfigSkeleton)
+178 tdecore (KConfigDialogManager)
+179 tdecore (KNetwork resolver)
+180 tdecore (kdelibs)
+200 tdeui (KMainWindow)
+220 tdeui (KToolBar)
+230 tdeui (KCommand)
+240 tdeui (kdelibs)
250 kfile (kdelibs)
-264 kdecore (KIconLoader)
-265 kdecore (KIconEffect)
-270 kdeui (KRootPixmap)
-280 kdeui (KSharedPixmap)
-281 kdeui (KCModule)
-282 kdeui (KDockWidget)
-290 kdeui (KPixmapIO)
-291 kdeui (KAboutDialog)
-292 kdeui (KComboBox)
-293 kdeui (KLineEdit)
-294 kdeui (KEdit)
-295 kdeui (KMenuBar)
-296 kdeui (KPopupMenu)
-298 kdeui (KDatePicker)
+264 tdecore (KIconLoader)
+265 tdecore (KIconEffect)
+270 tdeui (KRootPixmap)
+280 tdeui (KSharedPixmap)
+281 tdeui (KCModule)
+282 tdeui (KDockWidget)
+290 tdeui (KPixmapIO)
+291 tdeui (KAboutDialog)
+292 tdeui (KComboBox)
+293 tdeui (KLineEdit)
+294 tdeui (KEdit)
+295 tdeui (KMenuBar)
+296 tdeui (KPopupMenu)
+298 tdeui (KDatePicker)
399 kimgio
400 artskde
-500 kdeprint
+500 tdeprint
700 kutils (KSettings::Dialog)
701 kutils (KSettings::Dispatcher)
702 kutils (KPluginSelector)
@@ -61,7 +61,7 @@
780 kcmshell (kdelibs)
790 kimproxy (kdelibs)
800 kabapi (kdelibs)
-900 kdesu (kdelibs)
+900 tdesu (kdelibs)
912 ksmartcard (kdelibs)
@@ -74,8 +74,8 @@
1202 konqueror
1203 libkonq
1204 kdesktop
-1205 kdesud
-1206 kdesu
+1205 tdesud
+1206 tdesu
1207 kdesktop (Minicli)
1208 kcontrol
1210 kicker
@@ -151,7 +151,7 @@
5150 libkleopatra
-# kdepim
+# tdepim
5200 kitchensync
5201 kitchensync (Konnector)
5202 kitchensync (OpieKonnector)
diff --git a/kdecore/kdebug.cpp b/kdecore/kdebug.cpp
index 8b7b4d88d..ed1a3d60d 100644
--- a/kdecore/kdebug.cpp
+++ b/kdecore/kdebug.cpp
@@ -289,7 +289,7 @@ static void kDebugBackend( unsigned short nLevel, unsigned int nArea, const char
}
case 1: // Message Box
{
- // Since we are in kdecore here, we cannot use KMsgBox and use
+ // Since we are in tdecore here, we cannot use KMsgBox and use
// TQMessageBox instead
if ( !kDebug_data->aAreaName.isEmpty() )
aCaption += TQString("(%1)").arg( QString(kDebug_data->aAreaName) );
diff --git a/kdecore/kdelibs_export.h b/kdecore/kdelibs_export.h
index 5624fcddb..220657d0b 100644
--- a/kdecore/kdelibs_export.h
+++ b/kdecore/kdelibs_export.h
@@ -67,7 +67,7 @@
#endif /*_KDELIBS_EXPORT_H*/
-/* workaround for kdecore: stupid tqmoc's grammar doesn't accept two macros
+/* workaround for tdecore: stupid tqmoc's grammar doesn't accept two macros
between 'class' keyword and : */
#ifdef KDE_DEPRECATED
# ifndef KDECORE_EXPORT_DEPRECATED
diff --git a/kdecore/kglobal.h b/kdecore/kglobal.h
index c00279e1b..08e12767e 100644
--- a/kdecore/kglobal.h
+++ b/kdecore/kglobal.h
@@ -227,7 +227,7 @@ int KDECORE_EXPORT kasciistricmp( const char *str1, const char *str2 );
* support, site-independent access to the filesystem and a large number
* of other (but no less important) things.
*
- * All KDE applications should link to the kdecore library. Also, using a
+ * All KDE applications should link to the tdecore library. Also, using a
* KApplication derived class instead of TQApplication is almost
* mandatory if you expect your application to behave nicely within the
* KDE environment.
diff --git a/kdecore/kiconeffect.cpp b/kdecore/kiconeffect.cpp
index dddfba556..9c76c7e4d 100644
--- a/kdecore/kiconeffect.cpp
+++ b/kdecore/kiconeffect.cpp
@@ -1,7 +1,7 @@
/* vi: ts=8 sts=4 sw=4
* $Id$
*
- * This file is part of the KDE project, module kdecore.
+ * This file is part of the KDE project, module tdecore.
* Copyright (C) 2000 Geert Jansen
* with minor additions and based on ideas from
* Torsten Rahn
@@ -279,7 +279,7 @@ TQPixmap KIconEffect::apply(TQPixmap pixmap, int effect, float value,
return result;
}
-// Taken from KImageEffect. We don't want to link kdecore to kdeui! As long
+// Taken from KImageEffect. We don't want to link tdecore to tdeui! As long
// as this code is not too big, it doesn't seem much of a problem to me.
void KIconEffect::toGray(TQImage &img, float value)
diff --git a/kdecore/kiconeffect.h b/kdecore/kiconeffect.h
index b5f84cc20..a8e7b685e 100644
--- a/kdecore/kiconeffect.h
+++ b/kdecore/kiconeffect.h
@@ -1,6 +1,6 @@
/* vi: ts=8 sts=4 sw=4
*
- * This file is part of the KDE project, module kdecore.
+ * This file is part of the KDE project, module tdecore.
* Copyright (C) 2000 Geert Jansen
* with minor additions and based on ideas from
* Torsten Rahn
diff --git a/kdecore/kiconloader.cpp b/kdecore/kiconloader.cpp
index 62950e5d8..317a56add 100644
--- a/kdecore/kiconloader.cpp
+++ b/kdecore/kiconloader.cpp
@@ -2,7 +2,7 @@
*
* $Id$
*
- * This file is part of the KDE project, module kdecore.
+ * This file is part of the KDE project, module tdecore.
* Copyright (C) 2000 Geert Jansen
* Antonio Larrosa
*
diff --git a/kdecore/kiconloader.h b/kdecore/kiconloader.h
index f8ac3fbc7..b7f1478f6 100644
--- a/kdecore/kiconloader.h
+++ b/kdecore/kiconloader.h
@@ -1,6 +1,6 @@
/* vi: ts=8 sts=4 sw=4
*
- * This file is part of the KDE project, module kdecore.
+ * This file is part of the KDE project, module tdecore.
* Copyright (C) 2000 Geert Jansen
* Antonio Larrosa
*
diff --git a/kdecore/kiconloader_p.h b/kdecore/kiconloader_p.h
index e6ae13659..4a7695390 100644
--- a/kdecore/kiconloader_p.h
+++ b/kdecore/kiconloader_p.h
@@ -1,6 +1,6 @@
/* vi: ts=8 sts=4 sw=4
*
- * This file is part of the KDE project, module kdecore.
+ * This file is part of the KDE project, module tdecore.
* Copyright (C) 2000 Geert Jansen
* Antonio Larrosa
*
diff --git a/kdecore/kicontheme.cpp b/kdecore/kicontheme.cpp
index ea91ab418..0f7d3b605 100644
--- a/kdecore/kicontheme.cpp
+++ b/kdecore/kicontheme.cpp
@@ -2,7 +2,7 @@
*
* $Id$
*
- * This file is part of the KDE project, module kdecore.
+ * This file is part of the KDE project, module tdecore.
* Copyright (C) 2000 Geert Jansen
* Antonio Larrosa
*
diff --git a/kdecore/kicontheme.h b/kdecore/kicontheme.h
index 3a1f14fa4..d8e29d339 100644
--- a/kdecore/kicontheme.h
+++ b/kdecore/kicontheme.h
@@ -1,6 +1,6 @@
/* vi: ts=8 sts=4 sw=4
*
- * This file is part of the KDE project, module kdecore.
+ * This file is part of the KDE project, module tdecore.
* Copyright (C) 2000 Geert Jansen
* Antonio Larrosa
*
diff --git a/kdecore/klibloader.cpp b/kdecore/klibloader.cpp
index 1a90881df..290e23154 100644
--- a/kdecore/klibloader.cpp
+++ b/kdecore/klibloader.cpp
@@ -362,7 +362,7 @@ TQString KLibLoader::findLibrary( const char * name, const KInstance * instance
{
libfile = instance->dirs()->findResource( "lib", libname );
#ifndef NDEBUG
- if ( !libfile.isEmpty() && libname.left(3) == "lib" ) // don't warn for kdeinit modules
+ if ( !libfile.isEmpty() && libname.left(3) == "lib" ) // don't warn for tdeinit modules
kdDebug(150) << "library " << libname << " not found under 'module' but under 'lib'" << endl;
#endif
}
diff --git a/kdecore/kstartupinfo.cpp b/kdecore/kstartupinfo.cpp
index 98195e8e5..12825e805 100644
--- a/kdecore/kstartupinfo.cpp
+++ b/kdecore/kstartupinfo.cpp
@@ -24,7 +24,7 @@ DEALINGS IN THE SOFTWARE.
****************************************************************************/
-// kdDebug() can't be turned off in kdeinit
+// kdDebug() can't be turned off in tdeinit
#if 0
#define KSTARTUPINFO_ALL_DEBUG
#warning Extra KStartupInfo debug messages enabled.
@@ -66,7 +66,7 @@ DEALINGS IN THE SOFTWARE.
static const char* const NET_STARTUP_MSG = "_NET_STARTUP_INFO";
static const char* const NET_STARTUP_WINDOW = "_NET_STARTUP_ID";
// DESKTOP_STARTUP_ID is used also in kinit/wrapper.c ,
-// kdesu in both kdelibs and kdebase and who knows where else
+// tdesu in both kdelibs and kdebase and who knows where else
static const char* const NET_STARTUP_ENV = "DESKTOP_STARTUP_ID";
static bool auto_app_started_sending = true;
diff --git a/kdecore/kstartupinfo.h b/kdecore/kstartupinfo.h
index da3018d8c..807e484c5 100644
--- a/kdecore/kstartupinfo.h
+++ b/kdecore/kstartupinfo.h
@@ -49,7 +49,7 @@ class KStartupInfoPrivate;
*
* This class can be used to send information about started application,
* change the information and receive this information. For detailed
- * description, see kdelibs/kdecore/README.kstartupinfo.
+ * description, see kdelibs/tdecore/README.kstartupinfo.
*
* You usually don't need to use this class for sending the notification
* information, as KDE libraries should do this when an application is
diff --git a/kdecore/kuniqueapplication.cpp b/kdecore/kuniqueapplication.cpp
index 7cd0575cc..193aafcd3 100644
--- a/kdecore/kuniqueapplication.cpp
+++ b/kdecore/kuniqueapplication.cpp
@@ -164,7 +164,7 @@ KUniqueApplication::start()
::exit(255);
}
- // Try to launch kdeinit.
+ // Try to launch tdeinit.
startKdeinit();
regName = dc->registerAs(appName, false);
if (regName.isEmpty())
diff --git a/kdecore/libkdecore.nmcheck b/kdecore/libkdecore.nmcheck
index b8057d350..7c017a6e4 100644
--- a/kdecore/libkdecore.nmcheck
+++ b/kdecore/libkdecore.nmcheck
@@ -1,6 +1,6 @@
# KDE namespace check file
-# kdecore classes
+# tdecore classes
K*::*
# these should preferably go in some namespace in KDE4
@@ -48,7 +48,7 @@ kasciistricmp
# from libtldl
lt_dl*
-# from kdefakes
+# from tdefakes
setenv
unsetenv
usleep
diff --git a/kdecore/network/CMakeLists.txt b/kdecore/network/CMakeLists.txt
index e00fdd0c8..101da4843 100644
--- a/kdecore/network/CMakeLists.txt
+++ b/kdecore/network/CMakeLists.txt
@@ -13,8 +13,8 @@ include_directories(
${TQT_INCLUDE_DIRS}
${CMAKE_BINARY_DIR}
${CMAKE_CURRENT_BINARY_DIR}
- ${CMAKE_SOURCE_DIR}/kdecore
- ${CMAKE_BINARY_DIR}/kdecore
+ ${CMAKE_SOURCE_DIR}/tdecore
+ ${CMAKE_BINARY_DIR}/tdecore
)
@@ -35,9 +35,9 @@ install( FILES
install( FILES ipv6blacklist DESTINATION ${CONFIG_INSTALL_DIR} )
-##### kdecorenetwork ############################
+##### tdecorenetwork ############################
-set( target kdecorenetwork )
+set( target tdecorenetwork )
set( ${target}_SRCS
kresolver.cpp kresolvermanager.cpp kresolverworkerbase.cpp
diff --git a/kdecore/svgicons/CMakeLists.txt b/kdecore/svgicons/CMakeLists.txt
index 714925667..4f2345510 100644
--- a/kdecore/svgicons/CMakeLists.txt
+++ b/kdecore/svgicons/CMakeLists.txt
@@ -11,8 +11,8 @@
include_directories(
${TQT_INCLUDE_DIRS}
- ${CMAKE_BINARY_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdecore
+ ${CMAKE_BINARY_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdecore
${LIBART_INCLUDE_DIRS}
)
diff --git a/kdecore/tests/Makefile.am b/kdecore/tests/Makefile.am
index 71e6faa92..e35ae68a4 100644
--- a/kdecore/tests/Makefile.am
+++ b/kdecore/tests/Makefile.am
@@ -17,7 +17,7 @@
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301, USA.
-INCLUDES = -I$(top_srcdir)/kdecore $(all_includes)
+INCLUDES = -I$(top_srcdir)/tdecore $(all_includes)
AM_LDFLAGS = $(QT_LDFLAGS) $(X_LDFLAGS) $(KDE_RPATH)
diff --git a/kdecore/tests/testqtargs.cpp b/kdecore/tests/testqtargs.cpp
index 3853bc035..d1c8ff244 100644
--- a/kdecore/tests/testqtargs.cpp
+++ b/kdecore/tests/testqtargs.cpp
@@ -5,7 +5,7 @@
g++ -g -Wall -o testqtargs testqtargs.cpp -I/usr/X11R6/include \
-I/opt/qt3/include -I/opt/trinity/include -L/usr/X11R6/lib -L/opt/qt3/lib \
- -L/opt/trinity/lib -lqt -lkdecore
+ -L/opt/trinity/lib -lqt -ltdecore
if invoked like this ./testqtargs --bg blue --caption something --hello hi
@@ -28,7 +28,7 @@
--bg is aliased to --background but If you try it with --background or
-background, you get the same thing.
- in kdecore/kapplication.cpp, KCmdLineOption qt_options is defined and used
+ in tdecore/kapplication.cpp, KCmdLineOption qt_options is defined and used
by the static method Kapplication::addCmdLineOptions to add the Qt options
but its' entries look like this:
diff --git a/kded/CMakeLists.txt b/kded/CMakeLists.txt
index aa466d999..0b9a3d72a 100644
--- a/kded/CMakeLists.txt
+++ b/kded/CMakeLists.txt
@@ -14,10 +14,10 @@ include_directories(
${CMAKE_CURRENT_BINARY_DIR}
${CMAKE_BINARY_DIR}
${CMAKE_CURRENT_SOURCE_DIR}
- ${CMAKE_BINARY_DIR}/kdecore
+ ${CMAKE_BINARY_DIR}/tdecore
${CMAKE_SOURCE_DIR}/dcop
- ${CMAKE_SOURCE_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdeui
+ ${CMAKE_SOURCE_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdeui
${CMAKE_SOURCE_DIR}/kio
${CMAKE_SOURCE_DIR}/kio/kio
)
@@ -47,9 +47,9 @@ set( ${target}_SRCS
kded.cpp kdedmodule.cpp
)
-# we must to export kdeinit_kded-shared because various
+# we must to export tdeinit_kded-shared because various
# modules need this library
-tde_add_kdeinit_executable( ${target} AUTOMOC EXPORT
+tde_add_tdeinit_executable( ${target} AUTOMOC EXPORT
SOURCES ${${target}_SRCS}
LINK kio-shared
)
@@ -66,7 +66,7 @@ set( ${target}_SRCS
kctimefactory.cpp vfolder_menu.cpp
)
-tde_add_kdeinit_executable( ${target} AUTOMOC
+tde_add_tdeinit_executable( ${target} AUTOMOC
SOURCES ${${target}_SRCS}
LINK kio-shared
)
@@ -82,7 +82,7 @@ set( ${target}_SRCS
tde_add_executable( ${target}
SOURCES ${${target}_SRCS}
- LINK kdecore-shared
+ LINK tdecore-shared
DESTINATION ${BIN_INSTALL_DIR}
)
diff --git a/kded/Mainpage.dox b/kded/Mainpage.dox
index 47f010f9d..50c0493d8 100644
--- a/kded/Mainpage.dox
+++ b/kded/Mainpage.dox
@@ -4,7 +4,7 @@ TrinityD runs in the background and performs a number of small tasks. Some
of these tasks are built in, others are started on demand.
The chances are you are looking here because you want to write a
-TrinityD module. For that, see TrinityDModule in kdecore and the
+TrinityD module. For that, see TrinityDModule in tdecore and the
TrinityD
README.
@@ -21,6 +21,6 @@ Waldo Bastian \
*/
-// DOXYGEN_REFERENCES = kdecore kdeui kio
+// DOXYGEN_REFERENCES = tdecore tdeui kio
// DOXYGEN_SET_PROJECT_NAME = TrinityD
// vim:ts=4:sw=4:expandtab:filetype=doxygen
diff --git a/kded/Makefile.am b/kded/Makefile.am
index 554a0e536..c91804b4b 100644
--- a/kded/Makefile.am
+++ b/kded/Makefile.am
@@ -20,7 +20,7 @@
INCLUDES= -I$(srcdir)/.. -I$(top_srcdir) $(all_includes)
lib_LTLIBRARIES =
-kdeinit_LTLIBRARIES = kded.la kbuildsycoca.la
+tdeinit_LTLIBRARIES = kded.la kbuildsycoca.la
kded_la_LDFLAGS = $(all_libraries) -module -avoid-version
kded_la_LIBADD = $(LIB_KIO) $(LIB_QT) $(LIB_KDECORE) $(top_builddir)/dcop/libDCOP.la $(LIB_X11)
@@ -38,15 +38,15 @@ kbuildsycoca_la_SOURCES = kbuildsycoca.cpp kbuildservicetypefactory.cpp \
bin_PROGRAMS = kdontchangethehostname kde-menu kmimelist
-kdontchangethehostname_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kdontchangethehostname_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
kdontchangethehostname_LDADD = $(LIB_KDECORE)
kdontchangethehostname_SOURCES = khostname.cpp
-kmimelist_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kmimelist_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
kmimelist_LDADD = ../kio/libkio.la
kmimelist_SOURCES = kmimelist.cpp
-kde_menu_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kde_menu_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
kde_menu_LDADD = $(LIB_KIO)
kde_menu_SOURCES = kde-menu.cpp
diff --git a/kded/kde-menu.cpp b/kded/kde-menu.cpp
index 873ce154d..33faf6c7c 100644
--- a/kded/kde-menu.cpp
+++ b/kded/kde-menu.cpp
@@ -148,7 +148,7 @@ int main(int argc, char **argv)
args.append("--checkstamps");
TQString command = "kbuildsycoca";
TQCString _launcher = KApplication::launcher();
- if (!DCOPRef(_launcher, _launcher).call("kdeinit_exec_wait", command, args).isValid())
+ if (!DCOPRef(_launcher, _launcher).call("tdeinit_exec_wait", command, args).isValid())
{
qWarning("Can't talk to klauncher!");
command = KGlobal::dirs()->findExe(command);
diff --git a/kded/kded.cpp b/kded/kded.cpp
index 1d234ac06..2a634ff5c 100644
--- a/kded/kded.cpp
+++ b/kded/kded.cpp
@@ -75,17 +75,17 @@ static void runBuildSycoca(TQObject *callBackObj=0, const char *callBackSlot=0)
dataStream << TQString("kbuildsycoca") << args;
TQCString _launcher = KApplication::launcher();
- kapp->dcopClient()->callAsync(_launcher, _launcher, "kdeinit_exec_wait(TQString,TQStringList)", data, callBackObj, callBackSlot);
+ kapp->dcopClient()->callAsync(_launcher, _launcher, "tdeinit_exec_wait(TQString,TQStringList)", data, callBackObj, callBackSlot);
}
else
{
- KApplication::kdeinitExecWait( "kbuildsycoca", args );
+ KApplication::tdeinitExecWait( "kbuildsycoca", args );
}
}
static void runKonfUpdate()
{
- KApplication::kdeinitExecWait( "kconf_update", TQStringList(), 0, 0, "0" /*no startup notification*/ );
+ KApplication::tdeinitExecWait( "kconf_update", TQStringList(), 0, 0, "0" /*no startup notification*/ );
}
static void runDontChangeHostname(const TQCString &oldName, const TQCString &newName)
@@ -93,7 +93,7 @@ static void runDontChangeHostname(const TQCString &oldName, const TQCString &new
TQStringList args;
args.append(TQFile::decodeName(oldName));
args.append(TQFile::decodeName(newName));
- KApplication::kdeinitExecWait( "kdontchangethehostname", args );
+ KApplication::tdeinitExecWait( "kdontchangethehostname", args );
}
Kded::Kded(bool checkUpdates, bool new_startup)
diff --git a/kdefx/CMakeLists.txt b/kdefx/CMakeLists.txt
index 1c33bb8f6..1aa52627f 100644
--- a/kdefx/CMakeLists.txt
+++ b/kdefx/CMakeLists.txt
@@ -14,8 +14,8 @@ include_directories(
${CMAKE_CURRENT_BINARY_DIR}
${CMAKE_BINARY_DIR}
${CMAKE_CURRENT_SOURCE_DIR}
- ${CMAKE_BINARY_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdecore
+ ${CMAKE_BINARY_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdecore
)
link_directories(
@@ -33,7 +33,7 @@ install( FILES
##### libtdefx ##################################
-set( target kdefx )
+set( target tdefx )
set( ${target}_SRCS
kpixmap.cpp kpixmapsplitter.cpp kpixmapeffect.cpp
diff --git a/kdefx/Makefile.am b/kdefx/Makefile.am
index 5c88a6e7e..2b588ba54 100644
--- a/kdefx/Makefile.am
+++ b/kdefx/Makefile.am
@@ -26,8 +26,8 @@ lib_LTLIBRARIES = libtdefx.la
libtdefx_la_LDFLAGS = $(KDE_RPATH) $(KDE_MT_LDFLAGS) $(all_libraries) -no-undefined -version-info 6:0:2
libtdefx_la_LIBADD = $(LIB_QT) $(LIB_XRENDER) $(LIB_X11)
libtdefx_la_NMCHECK = $(srcdir)/libtdefx.nmcheck
-libtdefx_la_NMCHECKWEAK = $(srcdir)/libtdefx_weak.nmcheck $(top_srcdir)/kdecore/libqt-mt_weak.nmcheck \
- $(top_srcdir)/kdecore/standard_weak.nmcheck
+libtdefx_la_NMCHECKWEAK = $(srcdir)/libtdefx_weak.nmcheck $(top_srcdir)/tdecore/libqt-mt_weak.nmcheck \
+ $(top_srcdir)/tdecore/standard_weak.nmcheck
include_HEADERS = kpixmap.h kpixmapsplitter.h \
kpixmapeffect.h kimageeffect.h kdrawutil.h kstyle.h kcpuinfo.h
@@ -40,6 +40,6 @@ METASOURCES = AUTO
EXTRA_DIST = Mainpage.dox
-DOXYGEN_REFERENCES = kdecore
+DOXYGEN_REFERENCES = tdecore
include ../admin/Doxyfile.am
diff --git a/kdefx/libkdefx.nmcheck b/kdefx/libkdefx.nmcheck
index a0bf7e60c..bebebf28c 100644
--- a/kdefx/libkdefx.nmcheck
+++ b/kdefx/libkdefx.nmcheck
@@ -1,6 +1,6 @@
# KDE namespace check file
-# kdefx classes
+# tdefx classes
K*::*
# these should preferably go in some namespace in KDE4
diff --git a/kdeprint/CMakeLists.txt b/kdeprint/CMakeLists.txt
index fa77fd3b4..bdbacc0bb 100644
--- a/kdeprint/CMakeLists.txt
+++ b/kdeprint/CMakeLists.txt
@@ -26,12 +26,12 @@ include_directories(
${CMAKE_CURRENT_BINARY_DIR}
${CMAKE_BINARY_DIR}
${CMAKE_CURRENT_SOURCE_DIR}
- ${CMAKE_BINARY_DIR}/kdecore
+ ${CMAKE_BINARY_DIR}/tdecore
${CMAKE_SOURCE_DIR}
${CMAKE_SOURCE_DIR}/dcop
- ${CMAKE_SOURCE_DIR}/kdefx
- ${CMAKE_SOURCE_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdeui
+ ${CMAKE_SOURCE_DIR}/tdefx
+ ${CMAKE_SOURCE_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdeui
${CMAKE_SOURCE_DIR}/kio
${CMAKE_SOURCE_DIR}/kio/kio
${CMAKE_SOURCE_DIR}/kio/kfile
@@ -53,16 +53,16 @@ install( FILES
kprintdialogpage.h kpreloadobject.h kmmanager.h
kmprinter.h kmobject.h kprintdialog.h driver.h
kmjobmanager.h kmjob.h
- DESTINATION ${INCLUDE_INSTALL_DIR}/kdeprint )
+ DESTINATION ${INCLUDE_INSTALL_DIR}/tdeprint )
##### other data ################################
install( FILES kprintpreviewui.rc DESTINATION ${CONFIG_INSTALL_DIR}/ui )
-install( FILES testprint.ps specials.desktop DESTINATION ${DATA_INSTALL_DIR}/kdeprint )
-install( FILES kdeprintd.desktop DESTINATION ${SERVICES_INSTALL_DIR}/kded )
-install( FILES kdeprintrc DESTINATION ${CONFIG_INSTALL_DIR} )
-install( FILES kdeprintrc.upd DESTINATION ${KCONF_UPDATE_INSTALL_DIR} )
+install( FILES testprint.ps specials.desktop DESTINATION ${DATA_INSTALL_DIR}/tdeprint )
+install( FILES tdeprintd.desktop DESTINATION ${SERVICES_INSTALL_DIR}/kded )
+install( FILES tdeprintrc DESTINATION ${CONFIG_INSTALL_DIR} )
+install( FILES tdeprintrc.upd DESTINATION ${KCONF_UPDATE_INSTALL_DIR} )
##### driverparse ###############################
@@ -74,25 +74,25 @@ tde_add_library( ${target} STATIC_PIC
)
-##### kded_kdeprintd ############################
+##### kded_tdeprintd ############################
-set( target kded_kdeprintd )
+set( target kded_tdeprintd )
set( ${target}_SRCS
- kdeprintd.cpp kprintprocess.cpp kdeprintd.skel
+ tdeprintd.cpp kprintprocess.cpp tdeprintd.skel
)
tde_add_kpart( ${target} AUTOMOC
SOURCES ${${target}_SRCS}
- LINK kio-shared kdeinit_kded-shared
+ LINK kio-shared tdeinit_kded-shared
DEPENDENCIES dcopidl dcopidl2cpp
DESTINATION ${PLUGIN_INSTALL_DIR}
)
-#### kdeprint ###################################
+#### tdeprint ###################################
-set( target kdeprint )
+set( target tdeprint )
set( ${target}_SRCS
kmfactory.cpp kmjob.cpp kmjobmanager.cpp kmmanager.cpp
@@ -103,7 +103,7 @@ set( ${target}_SRCS
kpcopiespage.cpp kpdriverpage.cpp kprinterpropertydialog.cpp
kpgeneralpage.cpp kpqtpage.cpp kmthreadjob.cpp
kpipeprocess.cpp kpfilterpage.cpp kmspecialmanager.cpp
- kdeprintcheck.cpp plugincombobox.cpp kpreloadobject.cpp
+ tdeprintcheck.cpp plugincombobox.cpp kpreloadobject.cpp
kfilelist.cpp kprintaction.cpp kpfileselectpage.cpp
treecombobox.cpp kxmlcommand.cpp util.cpp printerfilter.cpp
marginpreview.cpp marginvaluewidget.cpp marginwidget.cpp
diff --git a/kdeprint/ChangeLog b/kdeprint/ChangeLog
index 182044501..5ce11bd36 100644
--- a/kdeprint/ChangeLog
+++ b/kdeprint/ChangeLog
@@ -1,10 +1,10 @@
-Since 2.2 release, Michael Goffioul
+Since 2.2 release, Michael Goffioul
* automatic filtering: if the input file format is not directly supported
- by the print spooler, kdeprint will try to convert the file to the
+ by the print spooler, tdeprint will try to convert the file to the
primary supported input format (usually PostScript). To achieve this,
- kdeprint uses the available filters (defined in XML files) and tries to
+ tdeprint uses the available filters (defined in XML files) and tries to
build up a filter chain.
- * mime type checking: when building a filter chain, kdeprint checks that
+ * mime type checking: when building a filter chain, tdeprint checks that
each output format is supported as an input by the next filter
* possibility to specify input file from the print dialog in StandAlone
mode (like XPP)
@@ -20,7 +20,7 @@ Since 2.2 release, Michael Goffioul
* print dialog: possibility to select the files to print in standalone
mode (like XPP).
-27/08/2001 Michael Goffioul
+27/08/2001 Michael Goffioul
* implementation of "Schedule" tab in print dialog for the CUPS plugin
(job-hold-until attribute).
* Printer aliases are now handled gracefully in the LPR plugin (they
@@ -29,30 +29,30 @@ Since 2.2 release, Michael Goffioul
setOption("kde-isspecial", "1");
setOption("kde-special-command", cmd);
-28/08/2001 Michael Goffioul
+28/08/2001 Michael Goffioul
* implementation of KPrintAction, which provides a quick access to
a class of printers (special, regular or both). An application just
needs to create a KPrintAction anc connect to print(KPrinter*).
-31/08/2001 Michael Goffioul
+31/08/2001 Michael Goffioul
* CUPS plugin: fix crash for Qt3 port, must check if attr->name is NULL
before comparing it with strcmp or strncmp.
-12/09/2001 Michael Goffioul
+12/09/2001 Michael Goffioul
* Management library: set all toolbars non movable to avoid move handles
-13/09/2001 Michael Goffioul
+13/09/2001 Michael Goffioul
* CUPS plugin: fix multiple showing of password dialog for password-
protected printers (timer is now blocked when the password dialog is
shown)
-14/09/2001 Michael Goffioul
+14/09/2001 Michael Goffioul
* CUPS plugin: configuration wizard rewritten using the structure of
ESP PrintPro: more consistent, less pages and widgets. Not used as
default config wizard yet.
* QList -> QPtrList
-25/09/2001 Michael Goffioul
+25/09/2001 Michael Goffioul
* CUPS plugin: made the new configuration wizard as default one.
* other QList -> QPtrList fixes (committed to CVS)
* Avoid to call plugin functions "completePrinter" for pseudo
@@ -64,21 +64,21 @@ Since 2.2 release, Michael Goffioul
* Wizard: fix buffer overflow when adding a remote LPD queue having
a lot of jobs waiting
-03/10/2001 Michael Goffioul
+03/10/2001 Michael Goffioul
* CUPS plugin: make use of GET/PUT request to handle configuration
file. Possibility to admin a remote CUPS server (if allowed)
* CUPS plugin: added "/jobs" in the available resources list
-09/10/2001 Michael Goffioul
+09/10/2001 Michael Goffioul
* CUPS plugin: added 2 missing pages in stand-alone mode, "Image"
and "Text".
-10/10/2001 Michael Goffioul
+10/10/2001 Michael Goffioul
* CUPS plugin: "HP-GL/2" page added
* General: added a GUI to configure the preview program, into the
config dialog of the print manager
-12/10/2001 Michael Goffioul
+12/10/2001 Michael Goffioul
* general: added the possibility for a plugin to add new actions
to the toolbar and context menu (main use = export driver in
CUPS).
@@ -86,16 +86,16 @@ Since 2.2 release, Michael Goffioul
through samba. Threaded operation with progress bar to notify
the user. Graphical equivalent to cupsaddsmb from cups-1.1.11.
-16/10/2001 Michael Goffioul
+16/10/2001 Michael Goffioul
* CUPS plugin: removed the "file" backend as it doesn't seem to
be available since a couple of releases, and added a "Other"
page to the wizard for any third-party backend (like pdf).
-18/10/2001 Michael Goffioul
- * kdeprintfax: don't hardcode program path, use the $PATH variable
+18/10/2001 Michael Goffioul
+ * tdeprintfax: don't hardcode program path, use the $PATH variable
first to find the program. Default to /usr/bin if not found.
-02/11/2001 Michael Goffioul
+02/11/2001 Michael Goffioul
* CUPS plugin:
. fix for remote printers when there's also a local
printer with the same name: the printer-uri-supported
@@ -104,22 +104,22 @@ Since 2.2 release, Michael Goffioul
as well as detected IPP printers on the network (in
the wizard)
-05/11/2001 Michael Goffioul
- * kdeprintfax: added possibility to view files being faxed and
+05/11/2001 Michael Goffioul
+ * tdeprintfax: added possibility to view files being faxed and
file action (remove and view) are enabled only when needed.
* KPrinter: when printing to a file, support encoding and spaces
in file names + system --> KProcess.
-07/11/2001 Michael Goffioul
- * kdeprint: fixed some problems:
- . collate entirely handled by kdeprint, even in the case
+07/11/2001 Michael Goffioul
+ * tdeprint: fixed some problems:
+ . collate entirely handled by tdeprint, even in the case
of page selection on application-side.
. set KPrinter object in KPrintDialog before adding other
dialog pages (some pages may need it)
* wizard: changed button layout and added a side graphic. Not
committed as the graphic comes from HP driver (copyright).
-08/11/2001 Michael Goffioul
+08/11/2001 Michael Goffioul
* CUPS plugin:
. complete IPP report for job added
. implementation of dynamically added plugin menus for
@@ -127,24 +127,24 @@ Since 2.2 release, Michael Goffioul
. printer infos are now retrieved from the correct host
for remote printers and classes (idem for IPP report)
* general: implementation of a DCOP signal communication to
- synchronize all kdeprint apps, a plugin change in one app is
+ synchronize all tdeprint apps, a plugin change in one app is
notified to all other opened apps (via DCOP).
* kicker extension: made extension aware of plugin change in
other apps (using new DCOP signal comm).
-09/11/2001 Michael Goffioul
+09/11/2001 Michael Goffioul
* CUPS plugin: added the possibility to list jobs on remote
printers. No management is allowed on remote jobs (yet?).
-10/11/2001 Michael Goffioul
+10/11/2001 Michael Goffioul
* general: use KShellProcess::quote() for any quoting. Normally,
all quoting problem should be fixed now.
-12/11/2001 Michael Goffioul
+12/11/2001 Michael Goffioul
* CUPS: redesigned the "cups-add-smb" dialog to make it more
user-driendly.
-13/11/2001 Michael GOffioul
+13/11/2001 Michael GOffioul
* general: implementation of a KActiveLabel class to embed active
links in labels. Clicking on it "exec" the associated URL.
* general: make use of KActiveLabel in the first page of the
@@ -154,7 +154,7 @@ Since 2.2 release, Michael Goffioul
correctly when scanning the network (however it should be
avoided as smbspool seems to be unable to handle it).
-14/11/2001 Michael Goffioul
+14/11/2001 Michael Goffioul
* ioslave: uploaded new templates from Chris (which adds support
for pseudo printers
* manager: modified RootOnly message for better consistency between
@@ -168,13 +168,13 @@ Since 2.2 release, Michael Goffioul
. added hiding mechanism to make the dialog more compact
(show/hide button can probably be improved)
-15/11/2001 Michael Goffioul
+15/11/2001 Michael Goffioul
* CUPS: drivers are now downloaded from the actual server for remote
printers. This allows to have access to all options set for any
printer (even remote ones). However remote printer's drivers are
kept read-only.
-16/11/2001 Michael Goffioul
+16/11/2001 Michael Goffioul
* print dialog: instances are now presented in a tree structure in
the combo box -> cleaner view.
* general: ported the use of a global instance file to 2.2 branch
@@ -185,7 +185,7 @@ Since 2.2 release, Michael Goffioul
numerical option and update the corresponding enum one with the
closest value.
-21/11/2001 Michael Goffioul
+21/11/2001 Michael Goffioul
* job viewer: clicking on 'x' button only hide the job viewer but
doesn't quit the app. To quit, either use menu item (from window
or system tray) or accel when job viewer is visible.
@@ -193,13 +193,13 @@ Since 2.2 release, Michael Goffioul
it is always centered on its parent now. It also have the dialog
buttons in title bar (no minimize).
-23/11/2001 Michael Goffioul
+23/11/2001 Michael Goffioul
* job management: the job management has been re-engineered to follow
the paradigm "1 window == 1 queue". There's still the possibility to
view jobs for all printers within a single window. This should enhance
the usability of job management tools (I hope).
-26/11/2001 Michael Goffioul
+26/11/2001 Michael Goffioul
* job management: job type (active/completed) is now handled on a
printer basis instead of a global property of the manager. This allows
different windows to show different job type, and also ease the
@@ -214,21 +214,21 @@ Since 2.2 release, Michael Goffioul
This new mechanism should also be applied to print management dynamic
actions (more consistent).
-28/11/2001 Michael Goffioul
+28/11/2001 Michael Goffioul
* special printers: added the possibility to have configurable options
in pseudo-printers. Options are described in an additional XML file
(like filters) and configured through an "Advanced" tab in the property
dialog. TODO: graphical configuration widget + apply KXmlCommand to
normal filters.
-29/11/2001 Michael Goffioul
+29/11/2001 Michael Goffioul
* general: fixed sorting of options in driver view. They should be shown
in order of appearance now.
* general: make use of the new KXmlCommand class for filters too.
* filters: removed the "Page Size" from the options of enscript filter,
this is taken from the KPrinter object now.
-04/12/2001 Michael Goffioul
+04/12/2001 Michael Goffioul
* general: finalized the new XML command mechanism:
. graphical command builder
. pseudo-printers and filters are completely based on new XML
@@ -236,14 +236,14 @@ Since 2.2 release, Michael Goffioul
previous mechanism are not used).
. KPrintFilter and KMFilterManager are now obsolete and replaced
by KXmlCommand and KXmlCommandManager respectively.
- * kdeprintfax: made the log window a "real" log window. It is dynamically
+ * tdeprintfax: made the log window a "real" log window. It is dynamically
refreshed on new debug output arrival (suggested by user).
-10/12/2001 Michael Goffioul
+10/12/2001 Michael Goffioul
* general: make use of "Detail" mechanism of KDialogBase in XML command
editor.
-11/12/2001 Michael Goffioul
+11/12/2001 Michael Goffioul
* instances: for root, instances are saved in global file
/etc/cups/lpoptions. This allows to easily create global instances
(just be root and create the instance).
@@ -251,17 +251,17 @@ Since 2.2 release, Michael Goffioul
file, such that root is able to manage global pseudo printers. Locale
pseudo printers still override global ones if they have the same name.
-12/12/2001 Michael Goffioul
+12/12/2001 Michael Goffioul
* general: added error messages when the printer list cannot be retrieved
in print manager and print dialog. With CUPS, if the server is not
running, an error message is shown to the user.
* CUPS: disabled all backends if no server is running.
-13/12/2001 Michael Goffioul
+13/12/2001 Michael Goffioul
* general: preleminary support for external printer tool. Only escputil
at this moment.
-03/01/2002 Michael Goffioul
+03/01/2002 Michael Goffioul
* general:
. added a "ID name" label to the first dialog for command editing
. put "View Printer Infos" in front of orientation and view type
@@ -273,12 +273,12 @@ Since 2.2 release, Michael Goffioul
. added a WhatsThis help to the "Instances" tab briefly explaining
what's an instance.
-09/01/2002 Michael Goffioul
+09/01/2002 Michael Goffioul
* general: when filtering, the file type is checked against supported
formats. If the format is not supported, a warning is issued and the
user has the possibility to auto-convert the file to a supported
format. Consequence: you can now safely perform page selection on any
- file type with any printer and any spooler, kdeprint will try to convert
+ file type with any printer and any spooler, tdeprint will try to convert
the file to PS.
* preview dialog: rewrote the code in a cleaner way, avoiding the use
of a non toplevel main window. Preview dialog looks simpler now. New
@@ -293,10 +293,10 @@ Since 2.2 release, Michael Goffioul
Netscape. If files are given on the command line, this option is
forced unset.
. added a "--nodialog" option for quick print.
- . added the persistent feature (with some code rewrite in kdeprint
+ . added the persistent feature (with some code rewrite in tdeprint
library)
-10/01/2002 Michael Goffioul
+10/01/2002 Michael Goffioul
* general: added (temporary) workaround for drawing problems in fixed
toolbars, until a real fix gets implemented:
static_cast(tb)->layout()->setMargin(1);
@@ -304,18 +304,18 @@ Since 2.2 release, Michael Goffioul
* general: added KPrinter::autoConfigure(), to automatically configure
a KPrinter object without the need for a print dialog.
-14/01/2002 Michael Goffioul
+14/01/2002 Michael Goffioul
* slave: made case-insensitive for backward compatibility (old URLs may
come from history). Now print:/Classes should work OK.
* CUPS: moved the IPP report to an separate dialog and added the
possibility to print the result.
-15/01/2002 Michael Goffioul
+15/01/2002 Michael Goffioul
* started the implementation of a new LPR/LPRng plugin: this implementation
is designed to be modular to provide support for various systems like
Foomatic, APSFilter, GNUlpr or Printtool(RH).
-17/01/2002 Michael Goffioul
+17/01/2002 Michael Goffioul
* LPR: first implementation of a job manager. Make use of asynchronous
lpc and lpq processes. Major problem: delay between new state and
screen update due to the fact that data are started to be updated when
@@ -326,22 +326,22 @@ Since 2.2 release, Michael Goffioul
the default basename for output file.
* test: updated to Qt3 and demonstrate the use of the DocFileName feature
-21/01/2002 Michael Goffioul
+21/01/2002 Michael Goffioul
* LPR: added basic implementation of a KPrinterImpl object -> plugin is
functional (though far from complete...)
-22/01/2002 Michael Goffioul
- * kdeprintfax: make use of new address book (libkabc) instead of the old
+22/01/2002 Michael Goffioul
+ * tdeprintfax: make use of new address book (libkabc) instead of the old
one (libkab).
-29/01/2002 Michael Goffioul
+29/01/2002 Michael Goffioul
* LPR: enhancement of the APSFilter handler. Still missing: setup the
options in the print command line
* wizard: removed the garbage '&' in last page
* general: added SMB util functions -> to be used whenever it's
possible (CUPS plugin, Foomatic handler => TO BE DONE)
-30/01/2002 Michael Goffioul
+30/01/2002 Michael Goffioul
* general: use QGuardedPtr to keep KPrinterImpl object in KPrinter, this
should avoid some crashes.
* LPR:
@@ -350,7 +350,7 @@ Since 2.2 release, Michael Goffioul
. fix problem with rmote lpd queues: force lp= in
printcap entry
-07/02/2002 Michael Goffioul
+07/02/2002 Michael Goffioul
* job viewer: fix crash when switching the print plugin elsewhere and
there's some jobs shown + fix refresh problem when switching plugin
* general: fix small bug when removing a filter in "Filters" page
@@ -358,12 +358,12 @@ Since 2.2 release, Michael Goffioul
problem with non-docked vertical toolbars. Use plain QPushButton
instead, but this has some drawing problems in HighColor style.
-11/02/2002 Michael Goffioul
+11/02/2002 Michael Goffioul
* LPR: added support for LPRngTool+IFHP (not complete yet though)
* general: various fixes for crashes, inconsistencies, ...
-12/02/2002 Michael Goffioul
- * kdeprintfax: added %email to possible command tags. The e-mail address
+12/02/2002 Michael Goffioul
+ * tdeprintfax: added %email to possible command tags. The e-mail address
is retrieved from standard settings in KControl module. The tag can
also be used in the "Name" field of the options dialog
* LPR: completion of the LPRngTool handler + implementation of dynamic
@@ -375,7 +375,7 @@ Since 2.2 release, Michael Goffioul
* CUPS: configuration tool now handles gracefully unrecognized options,
a warning is issued, and they are restored as-is on file saving.
-13/02/2002 Michael Goffioul
+13/02/2002 Michael Goffioul
* CUPS: added support for job-billing and page-label, and put them
along with the scredule option into a single "Advanced" tab.
* CUPS: added job billing info to the job viewer
@@ -383,23 +383,23 @@ Since 2.2 release, Michael Goffioul
dialog
* general: allow multi selection in the file list of print dialog
-14/02/2002 Michael Goffioul
+14/02/2002 Michael Goffioul
* CUPS: added the possibility to edit job attributes on-the-fly using
a dialog similar to the printer properties dialog. Still the be fixed:
page ranges (problem with option encoding in CUPS).
-15/02/2002 Michael Goffioul
+15/02/2002 Michael Goffioul
* general: fixed infinite recursion bug in KIconSelectAction
* CUPS: temporarily disabled edition of page-ranges as it seems CUPS is
buggy. I should find a workaround.
* general (CUPS): enable some actions for jobs on remote hosts. It seems
to work OK between my local LM-8.1 and a remote LM-7.2.
-16/02/2002 Michael Goffioul
+16/02/2002 Michael Goffioul
* CUPS: added direct Foomatic driver support (no need the all PPD package
from foomatic anymore, driver are loaded directly from Foomatic)
-17/02/2002 Michael GOffioul
+17/02/2002 Michael GOffioul
* preview:
. better algorithm to find a preview object
. more comprehensive error report
@@ -407,11 +407,11 @@ Since 2.2 release, Michael Goffioul
* general: added the backend stuff for printer filtering, needs GUI
-> allows to only show a selected set of printers
-18/02/2002 Michael Goffioul
+18/02/2002 Michael Goffioul
* general: simple printer filtering mechanism based on printer name
and location regexp. Graphical configuration for printer name.
-19/02/2002 Michael Goffioul
+19/02/2002 Michael Goffioul
* general:
. completion of the printer filtering mechanism (added location
string filter)
@@ -420,16 +420,16 @@ Since 2.2 release, Michael Goffioul
. possibility to open the main option dialog from print dialog
(for example to change the filter or default preview program)
. added icon on push buttons when useful
- . changed plugin names to kdeprint_* (stripped the leading "lib")
+ . changed plugin names to tdeprint_* (stripped the leading "lib")
-20/02/2002 Michael Goffioul
+20/02/2002 Michael Goffioul
* slave: prevent konqueror to consider a trailing slash as a directory
specification (simply add a config entry in protocol file)
* general: large UI standardization by making use of KDialogBase along
with KGuiItem
* kicker menu: possibility to open main Options Dialog from the menu
-21/02/2002 Michael Goffioul
+21/02/2002 Michael Goffioul
* general: splitted the printer state into enable/disable and start/stop
and modified the GUI to reflect this
* general: removed the KMManager::configure(), obsoleted by the complete
@@ -437,22 +437,22 @@ Since 2.2 release, Michael Goffioul
* kicker extension: extension of the menu plugin to allow access to the
server configuration tool as well as the "kprinter" utility.
-25/02/2002 Michael Goffioul
+25/02/2002 Michael Goffioul
* LPR: added printer testing support
-26/02/2002 Michael Goffioul
+26/02/2002 Michael Goffioul
* general: printer filtering specs are now ORed instead of ANDed
* general: changed "Advanced" to "Driver Settings"
* CUPS: fixed RIPCache problem, added support for possible suffixes
-27/02/2002 Michael Goffioul
+27/02/2002 Michael Goffioul
* CUPS: workaround to allow special characters in login/password without
breaking security. Possible now to use safely chars like '@' and '/'
in login.
* general: added a check box in the config dialog to enable/disable
font embedding into PS data (compatible with Qt settings).
-28/02/2002 Michael Goffioul
+28/02/2002 Michael Goffioul
* general: job viewer updated correctly on plugin reload -> additional
columns and "history" action state
* general: internal *Settings objects are synchonized on config changes
@@ -460,11 +460,11 @@ Since 2.2 release, Michael Goffioul
* general: improved feedback to user when creating driver DB
* CUPS: speed optimization when creating driver DB (simple hack to avoid
to parse the entire PPD file each time => much better)
- * kdeprintfax: added "-n" and "-f %email" by default for the Hylafax
+ * tdeprintfax: added "-n" and "-f %email" by default for the Hylafax
system
* general: various small UI improvements (suggested by Thomas)
-02/03/2002 Michael Goffioul
+02/03/2002 Michael Goffioul
* general: modified the driver structure to support dynamic options
as in SuSE
* LPR: more management support for SuSE handler -> drver settings can
@@ -472,7 +472,7 @@ Since 2.2 release, Michael Goffioul
* general: needed stuff to provide translations for filters (Coolo will
now extract the strings from XML files for translators)
-10/03/2002 Michael Goffioul
+10/03/2002 Michael Goffioul
* CUPS: allow any integer value for RIPCache + don't upload the cupsd.conf
with wrong settings
@@ -480,7 +480,7 @@ Since 2.2 release, Michael Goffioul
* KDE-3 RELEASE *
*****************
-(CeBIT) Michael Goffioul
+(CeBIT) Michael Goffioul
* Fix various crashes:
. when changing the CUPS server (notify registered object before
reloading)
@@ -491,7 +491,7 @@ Since 2.2 release, Michael Goffioul
* general: started generealization of a margin widget to configure the
margins of the KPrinter object
-25/03/2002 Michael Goffioul
+25/03/2002 Michael Goffioul
* general: do not use pointers in various views, to avoid dangling
pointers (and crashes) when changing something (plugin, config file, ...).
This makes the aboutToReload functions quite useless, but it has to
@@ -502,13 +502,13 @@ Since 2.2 release, Michael Goffioul
* general: added help button to the wizard and the print dialog. They
are connected to the main help (should probably add an anchor to go
directly to the associated part).
- * kdeprintfax: more support/sync with standard addressbook:
- . possibility to start the ab editor from kdeprintfax
+ * tdeprintfax: more support/sync with standard addressbook:
+ . possibility to start the ab editor from tdeprintfax
. make use of the "Organization" field as enterprise
. fix problem with empty phone number (ex: no business fax).
-26/03/2002 Michael Goffioul
- * kdeprintfax:
+26/03/2002 Michael Goffioul
+ * tdeprintfax:
. added support for Mgetty-sendfax
. added support for page size in filters
. make use of the localized page size as default
@@ -518,19 +518,19 @@ Since 2.2 release, Michael Goffioul
. bugfix in logview: behaves safely when closed using the title
bar button
-27/03/2002 Michael Goffioul
+27/03/2002 Michael Goffioul
* general: created a separate "Fonts" section in the KDEPrint settings
dialog and removed the "Embed Fonts" option from the general section
(moved to the new section).
- * kdeprintfax: fixed disabled background for "Comment" widget, use QBrush
+ * tdeprintfax: fixed disabled background for "Comment" widget, use QBrush
instead of QColor. OK with styles like Liquid.
-28/03/2002 Michael Goffioul
+28/03/2002 Michael Goffioul
* general: added a user feedback mechanism in the form of a dialog showgin
status messages, including initialization, number of the page currently
generated, filtering and sending to the printer.
-29/03/2002 Michael Goffioul
+29/03/2002 Michael Goffioul
* general: enhanced the status feedback mechanism
. possibility to have multiple status boxes (one for each app)
. added an icon (eye-candy) and the document name being printed
@@ -545,7 +545,7 @@ Since 2.2 release, Michael Goffioul
current plugin below the plugin combobox (ex: in CUPS, shows the current
server:port).
-02/04/2002 Michael Goffioul
+02/04/2002 Michael Goffioul
* general:
. fixed various conflicting shortcuts
. made KMVirtualManager inherit from KPReloadObject to force instance
@@ -555,14 +555,14 @@ Since 2.2 release, Michael Goffioul
tab in the print dialog. It contain a 2-columns table where custom tags
can be added. Read-only in job editing mode (hope to change that soon).
-03/04/2002 Michael Goffioul
+03/04/2002 Michael Goffioul
* manager: show instances as children of the real printer in the tree view.
No instance management is possible from the tree view itself. The user
still has to use the "Instances" tab.
* ioslave: added support for print jobs browsing, per printer or for all
printers together (-> print:/jobs)
-04/04/2002 Michael Goffioul
+04/04/2002 Michael Goffioul
* ioslave: added support to view the driver of a printer in HTML form
(print:/printers/lp1?driver)
* CUPS: allows editing of page-ranges for pending jobs, work around
@@ -573,11 +573,11 @@ Since 2.2 release, Michael Goffioul
work with gpr (from GNUlpr)
. added support for "bool" directives in Foomatic drivers
-23/05/2002 Michael Goffioul
+23/05/2002 Michael Goffioul
* job manager: added the possibility to control the username for jobs
filtering, and the possibility to limit the number of jobs shown.
-16/08/2002 Michael Goffioul
+16/08/2002 Michael Goffioul
* filters/command: added the possibility to have comments about a specific
command, including clickable URL's. Modified the command selector to use
those comments.
@@ -589,31 +589,31 @@ Since 2.2 release, Michael Goffioul
even on first dialog showing (call slotPrinterSelected after setting
the output file name).
-20/08/2002 Michael Goffioul
+20/08/2002 Michael Goffioul
* print dialog:
. added a method to disable a page in the main dialog
. make the filename persistent in the SaveFile dialog
. use a rename dialog if the output file already exists
-26/08/2002 Michael Goffioul
+26/08/2002 Michael Goffioul
* general: added a generic PS driver to (missing for too long)
-02/09/2002 Michael Goffioul
+02/09/2002 Michael Goffioul
* print dialog: added graphical interface to the poster XML command
(still to be committed)
* manager: added a condensed toolbar with actions grouped by topics in
sub-menus.
-03/09/2002 Michael Goffioul
+03/09/2002 Michael Goffioul
* print dialog: enabled preview even in standalone mode, either the
internal PS viewer or any other registered app will be used,
according to the user preferences.
-04/09/2002 Michael Goffioul
+04/09/2002 Michael Goffioul
* commands: make unavailability of a command more visual by showing a
red text, and disabling the OK button of the current dialog (only
if needed).
-05/09/2002 Michael Goffioul
+05/09/2002 Michael Goffioul
* CUPS: shows all possible URI detected by CUPS when selecting the "Others"
printer type in the wizard, like the web interface is doing.
diff --git a/kdeprint/Makefile.am b/kdeprint/Makefile.am
index 8b63447e1..fecf25c64 100644
--- a/kdeprint/Makefile.am
+++ b/kdeprint/Makefile.am
@@ -6,14 +6,14 @@ endif
SUBDIRS = . management lpdunix $(CUPSSUBDIR) lpr rlpr ext filters pics tools tests
-INCLUDES= -I$(top_srcdir)/kdefx -I$(top_srcdir)/kded -I$(top_srcdir) $(all_includes)
+INCLUDES= -I$(top_srcdir)/tdefx -I$(top_srcdir)/kded -I$(top_srcdir) $(all_includes)
-kde_module_LTLIBRARIES = kded_kdeprintd.la
+kde_module_LTLIBRARIES = kded_tdeprintd.la
-kded_kdeprintd_la_SOURCES = kdeprintd.skel kdeprintd.cpp kprintprocess.cpp
-kded_kdeprintd_la_LIBADD = $(LIB_KIO) $(LIB_KDED) $(LIB_QT) $(LIB_KDEUI) $(top_builddir)/dcop/libDCOP.la $(LIB_KDECORE) $(top_builddir)/kded/libtdeinit_kded.la
-kded_kdeprintd_la_LDFLAGS = $(all_libraries) -module -avoid-version
-#kded_kdeprintd_la_METASOURCES = AUTO
+kded_tdeprintd_la_SOURCES = tdeprintd.skel tdeprintd.cpp kprintprocess.cpp
+kded_tdeprintd_la_LIBADD = $(LIB_KIO) $(LIB_KDED) $(LIB_QT) $(LIB_KDEUI) $(top_builddir)/dcop/libDCOP.la $(LIB_KDECORE) $(top_builddir)/kded/libtdeinit_kded.la
+kded_tdeprintd_la_LDFLAGS = $(all_libraries) -module -avoid-version
+#kded_tdeprintd_la_METASOURCES = AUTO
lib_LTLIBRARIES = libtdeprint.la
@@ -23,7 +23,7 @@ libtdeprint_la_SOURCES = kmfactory.cpp kmjob.cpp kmjobmanager.cpp kmmanager.cpp
kprintpreview.cpp kprintdialog.cpp kprinter.cpp kprinterimpl.cpp kprintdialogpage.cpp \
kpcopiespage.cpp kpdriverpage.cpp kprinterpropertydialog.cpp kpgeneralpage.cpp kpqtpage.cpp \
kmthreadjob.cpp kpipeprocess.cpp kpfilterpage.cpp \
- kmspecialmanager.cpp kdeprintcheck.cpp plugincombobox.cpp kpreloadobject.cpp kfilelist.cpp \
+ kmspecialmanager.cpp tdeprintcheck.cpp plugincombobox.cpp kpreloadobject.cpp kfilelist.cpp \
kprintaction.cpp kpfileselectpage.cpp treecombobox.cpp kmfactory.skel kxmlcommand.cpp \
util.cpp printerfilter.cpp marginpreview.cpp marginvaluewidget.cpp marginwidget.cpp \
kpmarginpage.cpp messagewindow.cpp posterpreview.cpp kpposterpage.cpp foomatic2loader.cpp \
@@ -38,8 +38,8 @@ noinst_HEADERS = kmdbentry.h kmfactory.h \
kmuimanager.h kmvirtualmanager.h driveritem.h droptionview.h \
driverview.h kprintpreview.h kprinterimpl.h kprintdialog.h \
kpcopiespage.h kpdriverpage.h kprinterpropertydialog.h kpgeneralpage.h \
- kpqtpage.h kprintprocess.h kmthreadjob.h kpipeprocess.h kdeprintd.h \
- kpfilterpage.h kmspecialmanager.h kdeprintcheck.h plugincombobox.h \
+ kpqtpage.h kprintprocess.h kmthreadjob.h kpipeprocess.h tdeprintd.h \
+ kpfilterpage.h kmspecialmanager.h tdeprintcheck.h plugincombobox.h \
kfilelist.h kpfileselectpage.h treecombobox.h kxmlcommand.h \
util.h driverparse.h printerfilter.h marginpreview.h marginwidget.h \
marginvaluewidget.h kpmarginpage.h messagewindow.h \
@@ -47,9 +47,9 @@ noinst_HEADERS = kmdbentry.h kmfactory.h \
include_HEADERS = kprinter.h kprintaction.h
-kdeprint_HEADERS = kprintdialogpage.h kpreloadobject.h kmmanager.h kmprinter.h kmobject.h kprintdialog.h \
+tdeprint_HEADERS = kprintdialogpage.h kpreloadobject.h kmmanager.h kmprinter.h kmobject.h kprintdialog.h \
driver.h kmjobmanager.h kmjob.h
-kdeprintdir = $(includedir)/kdeprint
+tdeprintdir = $(includedir)/tdeprint
EXTRA_DIST = fooparser.y fooscanner.l kprintpreviewui.rc
@@ -61,22 +61,22 @@ uidatadir = $(kde_confdir)/ui
# Test page
printdata_DATA = testprint.ps specials.desktop
-printdatadir = $(kde_datadir)/kdeprint
+printdatadir = $(kde_datadir)/tdeprint
# Services
servicesdir = $(kde_servicesdir)/kded
-services_DATA = kdeprintd.desktop
+services_DATA = tdeprintd.desktop
# Config file
configdir = $(kde_confdir)
-config_DATA = kdeprintrc
+config_DATA = tdeprintrc
# parser and scanner
fooparser:
rm -f fooparser.cpp.h
- bison -v -d -p kdeprint_foomatic2 $(srcdir)/fooparser.y -o $(srcdir)/fooparser.cpp
+ bison -v -d -p tdeprint_foomatic2 $(srcdir)/fooparser.y -o $(srcdir)/fooparser.cpp
if test -f "$(srcdir)/fooparser.hpp"; then mv $(srcdir)/fooparser.hpp $(srcdir)/fooparser.cpp.h; fi
- flex -o$(srcdir)/fooscanner.cpp -Pkdeprint_foomatic2 $(srcdir)/fooscanner.l
+ flex -o$(srcdir)/fooscanner.cpp -Ptdeprint_foomatic2 $(srcdir)/fooscanner.l
echo "#ifndef fooparser_cpp_h" > $(srcdir)/fooparser.cpp.hh
echo "#define fooparser_cpp_h" >> $(srcdir)/fooparser.cpp.hh
cat $(srcdir)/fooparser.cpp.h >> $(srcdir)/fooparser.cpp.hh
@@ -85,30 +85,30 @@ fooparser:
ppdparser:
rm -f ppdparser.cpp.h
- bison -v -d -p kdeprint_ppd $(srcdir)/ppdparser.y -o $(srcdir)/ppdparser.cpp
+ bison -v -d -p tdeprint_ppd $(srcdir)/ppdparser.y -o $(srcdir)/ppdparser.cpp
if test -f "$(srcdir)/ppdparser.hpp"; then mv $(srcdir)/ppdparser.hpp $(srcdir)/ppdparser.cpp.h; fi
- flex -o$(srcdir)/ppdscanner.cpp -Pkdeprint_ppd $(srcdir)/ppdscanner.l
+ flex -o$(srcdir)/ppdscanner.cpp -Ptdeprint_ppd $(srcdir)/ppdscanner.l
echo "#ifndef ppdparser_cpp_h" > $(srcdir)/ppdparser.cpp.hh
echo "#define ppdparser_cpp_h" >> $(srcdir)/ppdparser.cpp.hh
cat $(srcdir)/ppdparser.cpp.h >> $(srcdir)/ppdparser.cpp.hh
echo "#endif" >> $(srcdir)/ppdparser.cpp.hh
mv $(srcdir)/ppdparser.cpp.hh $(srcdir)/ppdparser.cpp.h
-noinst_DATA = kdeprint
+noinst_DATA = tdeprint
-kdeprint:
- $(LN_S) $(srcdir)/management kdeprint
+tdeprint:
+ $(LN_S) $(srcdir)/management tdeprint
# convenience static library
noinst_LIBRARIES = libdriverparse.a
libdriverparse_a_SOURCES = driverparse.c
-update_DATA = kdeprintrc.upd
+update_DATA = tdeprintrc.upd
updatedir = $(kde_datadir)/kconf_update
messages: rc.cpp
$(EXTRACTRC) `find . -name "*.rc" -o -name "*.ui" | grep -v /cupsdconf` >> rc.cpp
- $(XGETTEXT) `find . -name "*.cpp" | grep -v /cupsdconf` -o $(podir)/kdeprint.pot
+ $(XGETTEXT) `find . -name "*.cpp" | grep -v /cupsdconf` -o $(podir)/tdeprint.pot
include ../admin/Doxyfile.am
diff --git a/kdeprint/TODO b/kdeprint/TODO
index 8531c0380..7c67dccdb 100644
--- a/kdeprint/TODO
+++ b/kdeprint/TODO
@@ -16,14 +16,14 @@ WISHES
- Possibility to specify a different input slot for first page???
-- add "Subject" or "Regarding" to kdeprintfax interface: look first
+- add "Subject" or "Regarding" to tdeprintfax interface: look first
if this is possible in efax and/or hylafax
- add the possibility to view a printjob file (if possible)
- restarting server: use of "ps" in a subshell to get the pid, possibility
of authentification (put this into separate program that would restart
- itself using kdesu).
+ itself using tdesu).
- CUPS: a "Printer/Server Debugging Helper" would be nice: you could
vary the LogLevel there, restart the server, provide a viewer
diff --git a/kdeprint/cups/CMakeLists.txt b/kdeprint/cups/CMakeLists.txt
index c9f336558..2166cc08f 100644
--- a/kdeprint/cups/CMakeLists.txt
+++ b/kdeprint/cups/CMakeLists.txt
@@ -20,17 +20,17 @@ include_directories(
${CMAKE_CURRENT_BINARY_DIR}
${CMAKE_BINARY_DIR}
${CMAKE_CURRENT_SOURCE_DIR}
- ${CMAKE_BINARY_DIR}/kdecore
+ ${CMAKE_BINARY_DIR}/tdecore
${CMAKE_SOURCE_DIR}
${CMAKE_SOURCE_DIR}/dcop
- ${CMAKE_SOURCE_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdecore/network
- ${CMAKE_SOURCE_DIR}/kdeui
+ ${CMAKE_SOURCE_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdecore/network
+ ${CMAKE_SOURCE_DIR}/tdeui
${CMAKE_SOURCE_DIR}/kio
${CMAKE_SOURCE_DIR}/kio/kio
${CMAKE_SOURCE_DIR}/kio/kfile
- ${CMAKE_SOURCE_DIR}/kdeprint
- ${CMAKE_SOURCE_DIR}/kdeprint/management
+ ${CMAKE_SOURCE_DIR}/tdeprint
+ ${CMAKE_SOURCE_DIR}/tdeprint/management
)
link_directories(
@@ -40,13 +40,13 @@ link_directories(
##### other data ################################
-install( FILES cups.print DESTINATION ${DATA_INSTALL_DIR}/kdeprint/plugins )
-install( FILES preview.png preview-mini.png DESTINATION ${DATA_INSTALL_DIR}/kdeprint )
+install( FILES cups.print DESTINATION ${DATA_INSTALL_DIR}/tdeprint/plugins )
+install( FILES preview.png preview-mini.png DESTINATION ${DATA_INSTALL_DIR}/tdeprint )
-#### kdeprint_cups ##############################
+#### tdeprint_cups ##############################
-set( target kdeprint_cups )
+set( target tdeprint_cups )
set( ${target}_SRCS
cupsinfos.cpp ipprequest.cpp kmcupsfactory.cpp
@@ -62,7 +62,7 @@ set( ${target}_SRCS
tde_add_kpart( ${target} AUTOMOC
SOURCES ${${target}_SRCS}
- LINK kdeprint_management-shared ${CUPS_LIBRARIES}
+ LINK tdeprint_management-shared ${CUPS_LIBRARIES}
DESTINATION ${PLUGIN_INSTALL_DIR}
)
@@ -77,7 +77,7 @@ set( ${target}_SRCS
tde_add_executable( ${target}
SOURCES ${${target}_SRCS}
- LINK driverparse-static kdefakes-shared ${ZLIB_LIBRARIES} ${DL_LIBRARIES}
+ LINK driverparse-static tdefakes-shared ${ZLIB_LIBRARIES} ${DL_LIBRARIES}
DESTINATION ${BIN_INSTALL_DIR}
)
@@ -92,6 +92,6 @@ set( ${target}_SRCS
tde_add_executable( ${target}
SOURCES ${${target}_SRCS}
- LINK kdefakes-shared ${CUPS_LIBRARIES}
+ LINK tdefakes-shared ${CUPS_LIBRARIES}
DESTINATION ${BIN_INSTALL_DIR}
)
diff --git a/kdeprint/cups/Makefile.am b/kdeprint/cups/Makefile.am
index ed45a175e..6f3d7edec 100644
--- a/kdeprint/cups/Makefile.am
+++ b/kdeprint/cups/Makefile.am
@@ -2,11 +2,11 @@ AM_CPPFLAGS = -D_KDEPRINT_COMPILE
SUBDIRS = cupsdconf2
-INCLUDES= -I$(top_srcdir) -I$(top_srcdir)/kio -I$(top_srcdir)/kfile -I$(top_srcdir)/kdeprint -I$(top_srcdir)/kdeprint/management -I$(top_srcdir)/kdecore/network $(all_includes)
+INCLUDES= -I$(top_srcdir) -I$(top_srcdir)/kio -I$(top_srcdir)/kfile -I$(top_srcdir)/tdeprint -I$(top_srcdir)/tdeprint/management -I$(top_srcdir)/tdecore/network $(all_includes)
-kde_module_LTLIBRARIES = kdeprint_cups.la
+kde_module_LTLIBRARIES = tdeprint_cups.la
-kdeprint_cups_la_SOURCES = cupsinfos.cpp ipprequest.cpp kmcupsfactory.cpp kmcupsjobmanager.cpp \
+tdeprint_cups_la_SOURCES = cupsinfos.cpp ipprequest.cpp kmcupsfactory.cpp kmcupsjobmanager.cpp \
kmcupsmanager.cpp kmcupsuimanager.cpp kmpropbanners.cpp kmwbanners.cpp kmwipp.cpp \
kmwippselect.cpp kcupsprinterimpl.cpp kmcupsconfigwidget.cpp \
kmconfigcups.cpp kmconfigcupsdir.cpp kmwippprinter.cpp kmwfax.cpp kmwquota.cpp \
@@ -14,9 +14,9 @@ kdeprint_cups_la_SOURCES = cupsinfos.cpp ipprequest.cpp kmcupsfactory.cpp kmcups
imagepreview.cpp imageposition.cpp kpimagepage.cpp \
kptextpage.cpp kphpgl2page.cpp cupsaddsmb2.cpp kmwother.cpp ippreportdlg.cpp \
kptagspage.cpp
-kdeprint_cups_la_LDFLAGS = $(all_libraries) -module -avoid-version -no-undefined
-kdeprint_cups_la_LIBADD = $(top_builddir)/kdeprint/management/libtdeprint_management.la $(LIB_KIO) $(LIB_CUPS) $(LIB_QT) $(LIB_KDEPRINT) $(LIB_KDECORE) $(LIB_KDEUI)
-kdeprint_cups_la_METASOURCES = AUTO
+tdeprint_cups_la_LDFLAGS = $(all_libraries) -module -avoid-version -no-undefined
+tdeprint_cups_la_LIBADD = $(top_builddir)/tdeprint/management/libtdeprint_management.la $(LIB_KIO) $(LIB_CUPS) $(LIB_QT) $(LIB_KDEPRINT) $(LIB_KDECORE) $(LIB_KDEUI)
+tdeprint_cups_la_METASOURCES = AUTO
noinst_HEADERS = cupsinfos.h ipprequest.h kmcupsjobmanager.h kmcupsmanager.h kmcupsuimanager.h \
kmpropbanners.h kmwbanners.h kmwipp.h kmwippselect.h kcupsprinterimpl.h \
@@ -27,18 +27,18 @@ noinst_HEADERS = cupsinfos.h ipprequest.h kmcupsjobmanager.h kmcupsmanager.h kmc
bin_PROGRAMS = make_driver_db_cups cupsdoprint
make_driver_db_cups_SOURCES = make_driver_db_cups.c
-make_driver_db_cups_LDADD = ../libdriverparse.a $(top_builddir)/kdecore/libtdefakes.la $(LIBDL) $(LIBZ)
+make_driver_db_cups_LDADD = ../libdriverparse.a $(top_builddir)/tdecore/libtdefakes.la $(LIBDL) $(LIBZ)
make_driver_db_cups_LDFLAGS = $(all_libraries)
cupsdoprint_SOURCES = cupsdoprint.c
-cupsdoprint_LDADD = $(LIB_CUPS) $(top_builddir)/kdecore/libtdefakes.la
+cupsdoprint_LDADD = $(LIB_CUPS) $(top_builddir)/tdecore/libtdefakes.la
cupsdoprint_LDFLAGS = $(all_libraries)
entry_DATA = cups.print
-entrydir = $(kde_datadir)/kdeprint/plugins
+entrydir = $(kde_datadir)/tdeprint/plugins
misc_DATA = preview.png preview-mini.png
-miscdir = $(kde_datadir)/kdeprint
+miscdir = $(kde_datadir)/tdeprint
EXTRA_DIST = postscript.ppd.gz
diff --git a/kdeprint/cups/cupsaddsmb2.cpp b/kdeprint/cups/cupsaddsmb2.cpp
index f12653cbb..ca40a10a7 100644
--- a/kdeprint/cups/cupsaddsmb2.cpp
+++ b/kdeprint/cups/cupsaddsmb2.cpp
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul
+ * Copyright (c) 2001 Michael Goffioul
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/cups/cupsaddsmb2.h b/kdeprint/cups/cupsaddsmb2.h
index 266a50c6c..84166f53c 100644
--- a/kdeprint/cups/cupsaddsmb2.h
+++ b/kdeprint/cups/cupsaddsmb2.h
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul
+ * Copyright (c) 2001 Michael Goffioul
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/cups/cupsdconf2/CMakeLists.txt b/kdeprint/cups/cupsdconf2/CMakeLists.txt
index 914b18446..ceee1bc47 100644
--- a/kdeprint/cups/cupsdconf2/CMakeLists.txt
+++ b/kdeprint/cups/cupsdconf2/CMakeLists.txt
@@ -14,9 +14,9 @@ include_directories(
${CMAKE_CURRENT_BINARY_DIR}
${CMAKE_BINARY_DIR}
${CMAKE_CURRENT_SOURCE_DIR}
- ${CMAKE_BINARY_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdecore
- ${CMAKE_SOURCE_DIR}/kdeui
+ ${CMAKE_BINARY_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdecore
+ ${CMAKE_SOURCE_DIR}/tdeui
${CMAKE_SOURCE_DIR}/kio
${CMAKE_SOURCE_DIR}/kio/kio
${CMAKE_SOURCE_DIR}/kio/kfile
@@ -31,7 +31,7 @@ link_directories(
install( FILES
kde_logo.png cups_logo.png cupsd.conf.template
- DESTINATION ${DATA_INSTALL_DIR}/kdeprint )
+ DESTINATION ${DATA_INSTALL_DIR}/tdeprint )
#### cupsdconf ##################################
@@ -48,7 +48,7 @@ set( ${target}_SRCS
cups-util.c qdirmultilineedit.cpp sizewidget.cpp main.cpp
)
-tde_add_kdeinit_executable( ${target} AUTOMOC
+tde_add_tdeinit_executable( ${target} AUTOMOC
SOURCES ${${target}_SRCS}
LINK kio-shared ${CUPS_LIBRARIES}
)
diff --git a/kdeprint/cups/cupsdconf2/Makefile.am b/kdeprint/cups/cupsdconf2/Makefile.am
index 83426a5b6..434af6a3c 100644
--- a/kdeprint/cups/cupsdconf2/Makefile.am
+++ b/kdeprint/cups/cupsdconf2/Makefile.am
@@ -4,7 +4,7 @@ INCLUDES= -I$(top_srcdir) -I$(top_srcdir)/kio -I$(top_srcdir)/kfile $(all_includ
bin_PROGRAMS =
lib_LTLIBRARIES =
-kdeinit_LTLIBRARIES = cupsdconf.la
+tdeinit_LTLIBRARIES = cupsdconf.la
# library creation
cupsdconf_la_SOURCES = cupsdconf.cpp cupsddialog.cpp cupsdpage.cpp cupsdcomment.cpp cupsdsplash.cpp \
@@ -26,7 +26,7 @@ noinst_HEADERS = cupsdconf.h cupsdpage.h cupsddialog.h cupsdcomment.h cupsdsplas
# Data
cupsdconfdata_DATA = kde_logo.png cups_logo.png cupsd.conf.template
-cupsdconfdatadir = $(kde_datadir)/kdeprint
+cupsdconfdatadir = $(kde_datadir)/tdeprint
# Translations
messages:
diff --git a/kdeprint/cups/cupsdconf2/addressdialog.cpp b/kdeprint/cups/cupsdconf2/addressdialog.cpp
index 7e4f1bdd9..fab6a6fba 100644
--- a/kdeprint/cups/cupsdconf2/addressdialog.cpp
+++ b/kdeprint/cups/cupsdconf2/addressdialog.cpp
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul
+ * Copyright (c) 2001 Michael Goffioul
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/cups/cupsdconf2/addressdialog.h b/kdeprint/cups/cupsdconf2/addressdialog.h
index 7d241a080..7fdb6fb6f 100644
--- a/kdeprint/cups/cupsdconf2/addressdialog.h
+++ b/kdeprint/cups/cupsdconf2/addressdialog.h
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul
+ * Copyright (c) 2001 Michael Goffioul
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/cups/cupsdconf2/browsedialog.cpp b/kdeprint/cups/cupsdconf2/browsedialog.cpp
index 4cfc6099c..b337eb883 100644
--- a/kdeprint/cups/cupsdconf2/browsedialog.cpp
+++ b/kdeprint/cups/cupsdconf2/browsedialog.cpp
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul
+ * Copyright (c) 2001 Michael Goffioul
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/cups/cupsdconf2/browsedialog.h b/kdeprint/cups/cupsdconf2/browsedialog.h
index e75357e1d..8db12bc34 100644
--- a/kdeprint/cups/cupsdconf2/browsedialog.h
+++ b/kdeprint/cups/cupsdconf2/browsedialog.h
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul
+ * Copyright (c) 2001 Michael Goffioul
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/cups/cupsdconf2/cups-util.h b/kdeprint/cups/cupsdconf2/cups-util.h
index 1daf4050e..9c23c0c5e 100644
--- a/kdeprint/cups/cupsdconf2/cups-util.h
+++ b/kdeprint/cups/cupsdconf2/cups-util.h
@@ -1,6 +1,6 @@
/*
* This file is part of the KDE libraries
- * Copyright (c) 2001 Michael Goffioul
+ * Copyright (c) 2001 Michael Goffioul
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
diff --git a/kdeprint/cups/cupsdconf2/cupsd.conf.template b/kdeprint/cups/cupsdconf2/cupsd.conf.template
index ae1a4c362..08d4b9425 100644
--- a/kdeprint/cups/cupsdconf2/cupsd.conf.template
+++ b/kdeprint/cups/cupsdconf2/cupsd.conf.template
@@ -5,7 +5,7 @@
# in KDEPrint. The predecessors to KDEPrint in former KDE releases
# were KUPS and QtCUPS; they are deprecated and no longer maintained.
#
-# Author: Michael Goffioul
+# Author: Michael Goffioul
diff --git a/kdecore/kapplication.cpp b/kdecore/kapplication.cpp
index 1f0db7240..9fdcfbcb9 100644
--- a/kdecore/kapplication.cpp
+++ b/kdecore/kapplication.cpp
@@ -1440,18 +1440,18 @@ bool KApplication::sessionSaving() const
void KApplication::startKdeinit()
{
#ifndef Q_WS_WIN //TODO
- KInstance inst( "startkdeinitlock" );
- KLockFile lock( locateLocal( "tmp", "startkdeinitlock", &inst ));
+ KInstance inst( "starttdeinitlock" );
+ KLockFile lock( locateLocal( "tmp", "starttdeinitlock", &inst ));
if( lock.lock( KLockFile::LockNoBlock ) != KLockFile::LockOK ) {
lock.lock();
DCOPClient cl;
if( cl.attach())
return; // whoever held the lock has already started dcopserver
}
- // Try to launch kdeinit.
- TQString srv = KStandardDirs::findExe(TQString::tqfromLatin1("kdeinit"));
+ // Try to launch tdeinit.
+ TQString srv = KStandardDirs::findExe(TQString::tqfromLatin1("tdeinit"));
if (srv.isEmpty())
- srv = KStandardDirs::findExe(TQString::tqfromLatin1("kdeinit"), KGlobal::dirs()->kfsstnd_defaultbindir());
+ srv = KStandardDirs::findExe(TQString::tqfromLatin1("tdeinit"), KGlobal::dirs()->kfsstnd_defaultbindir());
if (srv.isEmpty())
return;
if (kapp && (Tty != kapp->type()))
@@ -2884,7 +2884,7 @@ void KApplication::invokeMailer(const TQString &_to, const TQString &_cc, const
TQString error;
// TODO this should check if cmd has a .desktop file, and use data from it, together
// with sending more ASN data
- if (kdeinitExec(cmd, cmdTokens, &error, NULL, startup_id ))
+ if (tdeinitExec(cmd, cmdTokens, &error, NULL, startup_id ))
if (Tty != kapp->type())
TQMessageBox::critical(kapp->mainWidget(), i18n("Could not Launch Mail Client"),
i18n("Could not launch the mail client:\n\n%1").arg(error), i18n("&OK"));
@@ -3006,7 +3006,7 @@ startServiceInternal( const TQCString &function,
// make sure there is id, so that user timestamp exists
stream << ( startup_id.isEmpty() ? KStartupInfo::createNewStartupId() : startup_id );
#endif
- if( function.left( 12 ) != "kdeinit_exec" )
+ if( function.left( 12 ) != "tdeinit_exec" )
stream << noWait;
if (!dcopClient->call(_launcher, _launcher,
@@ -3100,32 +3100,32 @@ KApplication::startServiceByDesktopName( const TQString& _name, const TQStringLi
}
int
-KApplication::kdeinitExec( const TQString& name, const TQStringList &args,
+KApplication::tdeinitExec( const TQString& name, const TQStringList &args,
TQString *error, int *pid )
{
- return kdeinitExec( name, args, error, pid, "" );
+ return tdeinitExec( name, args, error, pid, "" );
}
int
-KApplication::kdeinitExec( const TQString& name, const TQStringList &args,
+KApplication::tdeinitExec( const TQString& name, const TQStringList &args,
TQString *error, int *pid, const TQCString& startup_id )
{
- return startServiceInternal("kdeinit_exec(TQString,TQStringList,TQValueList,TQCString)",
+ return startServiceInternal("tdeinit_exec(TQString,TQStringList,TQValueList,TQCString)",
name, args, error, 0, pid, startup_id, false);
}
int
-KApplication::kdeinitExecWait( const TQString& name, const TQStringList &args,
+KApplication::tdeinitExecWait( const TQString& name, const TQStringList &args,
TQString *error, int *pid )
{
- return kdeinitExecWait( name, args, error, pid, "" );
+ return tdeinitExecWait( name, args, error, pid, "" );
}
int
-KApplication::kdeinitExecWait( const TQString& name, const TQStringList &args,
+KApplication::tdeinitExecWait( const TQString& name, const TQStringList &args,
TQString *error, int *pid, const TQCString& startup_id )
{
- return startServiceInternal("kdeinit_exec_wait(TQString,TQStringList,TQValueList,TQCString)",
+ return startServiceInternal("tdeinit_exec_wait(TQString,TQStringList,TQValueList,TQCString)",
name, args, error, 0, pid, startup_id, false);
}
diff --git a/kdecore/kapplication.h b/kdecore/kapplication.h
index 25ecb6ee3..f1be3bfb8 100644
--- a/kdecore/kapplication.h
+++ b/kdecore/kapplication.h
@@ -814,10 +814,10 @@ public:
TQString *error=0, TQCString *dcopService=0, int *pid = 0, const TQCString &startup_id = "", bool noWait = false );
/**
* Starts a program via kdeinit.
*
* program name and arguments are converted to according to the
* local encoding and passed as is to kdeinit.
*
* @param name Name of the program to start
* @param args Arguments to pass to the program
@@ -830,16 +830,16 @@ public:
* "" ( empty string ) is the default
* @return an error code indicating success (== 0) or failure (> 0).
*/
- static int kdeinitExec( const TQString& name, const TQStringList &args,
+ static int tdeinitExec( const TQString& name, const TQStringList &args,
TQString *error, int *pid, const TQCString& startup_id );
// KDE4 merge with above with startup_id = ""
- static int kdeinitExec( const TQString& name, const TQStringList &args=TQStringList(),
+ static int tdeinitExec( const TQString& name, const TQStringList &args=TQStringList(),
TQString *error=0, int *pid = 0 );
/**
* Starts a program via kdeinit and wait for it to finish.
*
* Like kdeinitExec(), but it waits till the program is finished.
* As such it behaves similar to the system(...) function.
*
* @param name Name of the program to start
@@ -853,10 +853,10 @@ public:
* "" ( empty string ) is the default
* @return an error code indicating success (== 0) or failure (> 0).
*/
- static int kdeinitExecWait( const TQString& name, const TQStringList &args,
+ static int tdeinitExecWait( const TQString& name, const TQStringList &args,
TQString *error, int *pid, const TQCString& startup_id );
// KDE4 merge with above with startup_id = ""
- static int kdeinitExecWait( const TQString& name, const TQStringList &args=TQStringList(),
+ static int tdeinitExecWait( const TQString& name, const TQStringList &args=TQStringList(),
TQString *error=0, int *pid = 0 );
/**
@@ -814,10 +814,10 @@ public:
TQString *error=0, TQCString *dcopService=0, int *pid = 0, const TQCString &startup_id = "", bool noWait = false );
/**
- * Starts a program via kdeinit.
+ * Starts a program via tdeinit.
*
* program name and arguments are converted to according to the
@@ -814,10 +814,10 @@ public:
*
* program name and arguments are converted to according to the
- * local encoding and passed as is to kdeinit.
+ * local encoding and passed as is to tdeinit.
*
* @param name Name of the program to start
@@ -830,16 +830,16 @@ public:
TQString *error=0, int *pid = 0 );
/**
- * Starts a program via kdeinit and wait for it to finish.
+ * Starts a program via tdeinit and wait for it to finish.
*
@@ -830,16 +830,16 @@ public:
*
- * Like kdeinitExec(), but it waits till the program is finished.
+ * Like tdeinitExec(), but it waits till the program is finished.
* As such it behaves similar to the system(...) function.
*
diff --git a/kdecore/kcrash.cpp b/kdecore/kcrash.cpp
index dd758f034..dbbd41338 100644
--- a/kdecore/kcrash.cpp
+++ b/kdecore/kcrash.cpp
@@ -177,7 +177,7 @@ KCrash::defaultCrashHandler (int sig)
argv[i++] = "--appname";
argv[i++] = appName;
if (KApplication::loadedByKdeinit)
- argv[i++] = "--kdeinit";
+ argv[i++] = "--tdeinit";
// only add apppath if it's not NULL
if (appPath) {
@@ -314,10 +314,10 @@ void KCrash::startDrKonqi( const char* argv[], int argc )
}
}
// If we can't reach kdeinit we can still at least try to fork()
void KCrash::startDirectly( const char* argv[], int )
{
- fprintf( stderr, "KCrash cannot reach kdeinit, launching directly.\n" );
+ fprintf( stderr, "KCrash cannot reach tdeinit, launching directly.\n" );
pid_t pid = fork();
if (pid <= 0)
{
@@ -483,13 +483,13 @@ static int openSocket()
return -1;
}
- if (strlen(sock_file)+strlen(display)+strlen("/kdeinit_")+2 > MAX_SOCK_FILE)
+ if (strlen(sock_file)+strlen(display)+strlen("/tdeinit_")+2 > MAX_SOCK_FILE)
{
fprintf(stderr, "Warning: Socket name will be too long.\n");
free(display);
return -1;
}
- strcat(sock_file, "/kdeinit_");
+ strcat(sock_file, "/tdeinit_");
strcat(sock_file, display);
free(display);
@@ -314,10 +314,10 @@ void KCrash::startDrKonqi( const char* argv[], int argc )
}
}
-// If we can't reach kdeinit we can still at least try to fork()
+// If we can't reach tdeinit we can still at least try to fork()
void KCrash::startDirectly( const char* argv[], int )
{
diff --git a/kdecore/ksycoca.cpp b/kdecore/ksycoca.cpp
index 2df7ae772..3a655d617 100644
--- a/kdecore/ksycoca.cpp
+++ b/kdecore/ksycoca.cpp
@@ -98,7 +98,7 @@ KSycoca::KSycoca()
}
// We register with DCOP _before_ we try to open the database.
// This way we can be relative sure that the KDE framework is
// up and running (kdeinit, dcopserver, klaucnher, kded) and
// that the database is up to date.
openDatabase();
_self = this;
@@ -332,7 +332,7 @@ TQDataStream * KSycoca::findFactory(KSycocaFactoryId id)
if (!triedLaunchingKdeinit) // try only once
{
triedLaunchingKdeinit = true;
- kdDebug(7011) << "findFactory: we have no database.... launching kdeinit" << endl;
+ kdDebug(7011) << "findFactory: we have no database.... launching tdeinit" << endl;
KApplication::startKdeinit();
// Ok, the new database should be here now, open it.
}
@@ -98,7 +98,7 @@ KSycoca::KSycoca()
// We register with DCOP _before_ we try to open the database.
// This way we can be relative sure that the KDE framework is
- // up and running (kdeinit, dcopserver, klaucnher, kded) and
+ // up and running (tdeinit, dcopserver, klaucnher, kded) and
// that the database is up to date.
openDatabase();